.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE OPERATOR CLASS" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE OPERATOR CLASS \- 新しい演算子クラスの定義

.SH SYNOPSIS
.sp
.nf
CREATE OPERATOR CLASS \fIname\fR [ DEFAULT ] FOR TYPE \fIdata_type\fR USING \fIindex_method\fR AS
  {  OPERATOR \fIstrategy_number\fR \fIoperator_name\fR [ ( \fIop_type\fR, \fIop_type\fR ) ] [ RECHECK ]
   | FUNCTION \fIsupport_number\fR \fIfuncname\fR ( \fIargument_type\fR [, ...] )
   | STORAGE \fIstorage_type\fR
  } [, ... ]
.sp
.fi
.SH "説明"
.PP
\fBCREATE OPERATOR CLASS\fRは新しい演算子クラスを定義します。
演算子クラスは、特定のデータ型がインデックスでどのように使用されるかを定義します。
演算子クラスにより、このデータ型およびインデックスメソッドの特定の役割もしくは``戦略''に、どの演算子を使用するかが指定されます。
また、インデックスの列に対する演算子クラスが選択される際に、演算子クラスによりインデックスメソッドで使用するサポートプロシージャが指定されます。
演算子クラスで使用される全ての演算子および関数は、演算子クラスを作成する前に定義しておく必要があります。
.PP
スキーマ名が与えられている場合、その演算子クラスは指定されたスキーマで作成されます。
スキーマ名がなければ、演算子クラスは現在のスキーマで作成されます。
異なるインデックスメソッドに使用する場合にのみ、同じスキーマ内の2つの演算子クラスに同じ名前を付けることができます。
.PP
演算子クラスを定義したユーザが、その所有者となります。
現在、演算子クラスを作成するユーザは、スーパーユーザである必要があります。
(誤った演算子クラスを定義すると、混乱の元となり、サーバクラッシュの原因とさえなり得るため、この制限が付けられています。)
.PP
現在、\fBCREATE OPERATOR CLASS\fRでは、インデックスメソッドに必要な全ての演算子および関数が、演算子クラス定義に含まれているかどうかを検査しません。
ユーザの責任において、有効な演算子クラスを定義してください。
.PP
詳細についてはthe documentationを参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
作成する演算子クラスの名前です。
演算子クラス名は、スキーマ修飾することができます。
.TP
\fBDEFAULT\fR
DEFAULTを付けると、その演算子クラスが、そのデータ型のデフォルトのインデックス演算子クラスになります。
特定のデータ型およびインデックスメソッドのデフォルトにできるのは、最大でも1つの演算子クラスのみです。
.TP
\fB\fIdata_type\fB\fR
この演算子クラスを使用する列のデータ型です。
.TP
\fB\fIindex_method\fB\fR
この演算子クラスを使用するインデックスメソッドの名前です。
.TP
\fB\fIstrategy_number\fB\fR
演算子クラスに関連する演算子のインデックスメソッドの戦略番号です。
.TP
\fB\fIoperator_name\fB\fR
演算子クラスに関連する演算子の名前です(スキーマ修飾名でも可)。
.TP
\fB\fIop_type\fB\fR
演算子の入力データ型、もしくは、左単項演算子か右単項演算子を表すNONEを指定します。
演算子クラスのデータ型と同じである通常の場合には、入力データ型は省略可能です。
.TP
\fBRECHECK\fR
RECHECKを付けると、インデックスが演算子に対して``損失の多い''状態であることを示します。
従って、インデックスを使用して抽出された行がこの演算子を含む条件句を実際に満たしているかを検証するために、この行を再度検査する必要があります。
.TP
\fB\fIsupport_number\fB\fR
演算子クラスに関連する関数用のインデックスメソッドのサポートプロシージャの番号です。
.TP
\fB\fIfuncname\fB\fR
演算子クラス用のインデックスメソッドのサポートプロシージャである関数の名前です (スキーマ修飾名でも可)。
.TP
\fB\fIargument_types\fB\fR
関数のパラメータのデータ型です。
.TP
\fB\fIstorage_type\fB\fR
インデックスに実際に格納されるデータ型です。
通常、このデータ型は列のデータ型と同じです。
しかし、異なるデータ型を許すインデックスメソッドもあります(執筆時にはGiSTのみ)。
インデックスメソッドで異なるデータ型の使用を許可していなければ、STORAGE句を省略する必要があります。
.PP
OPERATOR、FUNCTION、STORAGEは任意の順番で記述できます。
.PP
.SH "注釈"
.PP
演算子はSQL関数で定義してはなりません。
SQL関数はよく呼び出し元の問い合わせにインライン化されますので、オプティマイザでその問い合わせがインデックスに一致するかどうかを認識できなくなってしまいます。
.SH "例"
.PP
以下のコマンド例では、_int4データ型(\fBint4\fRの配列)のGiSTインデックス演算子クラスを定義しています。
この例の詳細については、\fIcontrib/intarray/\fRを参照してください。
.sp
.nf
CREATE OPERATOR CLASS gist__int_ops
    DEFAULT FOR TYPE _int4 USING gist AS
        OPERATOR        3       &&,
        OPERATOR        6       =       RECHECK,
        OPERATOR        7       @,
        OPERATOR        8       ~,
        OPERATOR        20      @@ (_int4, query_int),
        FUNCTION        1       g_int_consistent (internal, _int4, int4),
        FUNCTION        2       g_int_union (bytea, internal),
        FUNCTION        3       g_int_compress (internal),
        FUNCTION        4       g_int_decompress (internal),
        FUNCTION        5       g_int_penalty (internal, internal, internal),
        FUNCTION        6       g_int_picksplit (internal, internal),
        FUNCTION        7       g_int_same (_int4, _int4, internal);
.sp
.fi
.SH "互換性"
.PP
\fBCREATE OPERATOR CLASS\fRはPostgreSQLの拡張です。 
標準SQLには\fBCREATE OPERATOR CLASS\fR文はありません。
.SH "関連項目"
ALTER OPERATOR CLASS [\fBalter_operator_class\fR(l)], DROP OPERATOR CLASS [\fBdrop_operator_class\fR(l)]
