.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_getargcount" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_getargcount \- SPI_prepareにより準備された計画に必要とされる引数の数を返します。

.SH SYNOPSIS
.sp
.nf
int SPI_getargcount(void * \fIplan\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_getargcount\fRは、\fBSPI_prepare\fRにより準備された計画を実行する時に必要とされる引数の数を返します。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
（\fBSPI_prepare\fRで返される）実行計画です。
.SH "戻り値"
.PP
\fIplan\fRで想定される引数の数です。
\fIplan\fRが\fBNULL\fRの場合は\fBSPI_ERROR_ARGUMENT\fRが返ります。
