.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP TABLESPACE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP TABLESPACE \- テーブル空間の削除

.SH SYNOPSIS
.sp
.nf
DROP TABLESPACE \fItablespacename\fR
.sp
.fi
.SH "説明"
.PP
\fBDROP TABLESPACE\fRはシステムからテーブル空間を削除します。
.PP
テーブル空間はその所有者もしくはスーパーユーザによってのみ削除可能です。
テーブル空間を削除する前に、全てのデータベースオブジェクトが空になっていなければなりません。
現在のデータベース内のオブジェクトがテーブル空間を使用していなかったとしても、他のデータベース内のオブジェクトがそのテーブル空間上にあることがあります。
.SH "パラメータ"
.TP
\fB\fItablespacename\fB\fR
テーブル空間の名前です。
.SH "例"
.PP
mystuffテーブル空間をシステムから削除します。
.sp
.nf
DROP TABLESPACE mystuff;
.sp
.fi
.SH "互換性"
.PP
\fBDROP TABLESPACE\fRはPostgreSQLの拡張です。
.SH "関連項目"
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)], ALTER TABLESPACE [\fBalter_tablespace\fR(l)]
