.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP CONVERSION" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP CONVERSION \- 変換の削除

.SH SYNOPSIS
.sp
.nf
DROP CONVERSION \fIname\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP CONVERSION\fRを使用すると、以前に定義した変換を削除できます。
変換を削除するには、その変換を所有していなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
変換の名前です。
変換名はスキーマ修飾することもできます。
.TP
\fBCASCADE\fR
.TP
\fBRESTRICT\fR
これらのキーワードを指定しても、変換に対する依存関係がないため、効果はありません。
.SH "例"
.PP
mynameという名前の変換を削除します。
.sp
.nf
DROP CONVERSION myname;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBDROP CONVERSION\fR文はありません。
.SH "関連項目"
ALTER CONVERSION [\fBalter_conversion\fR(l)], CREATE CONVERSION [\fBcreate_conversion\fR(l)]
