.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE SCHEMA" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE SCHEMA \- 新しいスキーマの定義

.SH SYNOPSIS
.sp
.nf
CREATE SCHEMA \fIschemaname\fR [ AUTHORIZATION \fIusername\fR ] [ \fIschema_element\fR [ ... ] ]
CREATE SCHEMA AUTHORIZATION \fIusername\fR [ \fIschema_element\fR [ ... ] ]
.sp
.fi
.SH "説明"
.PP
\fBCREATE SCHEMA\fRを実行すると、現在のデータベースに新しいスキーマを登録します。
スキーマ名は、現在のデータベースにある既存のスキーマとは異なる名前にする必要があります。
.PP
スキーマは、本質的には名前空間です。
スキーマには、名前付きオブジェクト(テーブル、データ型、関数、および演算子)が含まれます。
これらのオブジェクトの名前は、他のスキーマに存在する他のオブジェクト名と重複してもかまいません。
名前付きオブジェクトには、スキーマ名を接頭辞としてオブジェクト名を``修飾''するか、あるいは必要なスキーマを含んだ検索パスを設定することによって、アクセスできます。
オブジェクト名を修飾しないで指定したCREATEコマンドは、そのオブジェクトを現在のスキーマ(\fBcurrent_schema\fR関数で決定できる、検索パスの先頭のものです。)で作成されます。
.PP
オプションで、\fBCREATE SCHEMA\fR には、新しいスキーマ内でオブジェクトを作成するためのサブコマンドを付加することができます。
サブコマンドは、本質的にはスキーマ作成後に発行される別コマンドと同じように扱われます。
ただし、AUTHORIZATION句が使用されている場合に、作成された全てのオブジェクトの所有者が指定したユーザになるという点で異なっています。
.SH "パラメータ"
.TP
\fB\fIschemaname\fB\fR
作成するスキーマの名前です。
省略された場合、ユーザ名がスキーマ名として使用されます。
この名前をpg_から始めることはできません。
こうした名前はシステムスキーマ用に予約されているためです。
.TP
\fB\fIusername\fB\fR
スキーマを所有するユーザの名前です。
省略された場合、デフォルトでこのコマンドを実行したユーザになります。
自分以外のユーザを所有者とするスキーマを作成できるのは、スーパーユーザだけです。
.TP
\fB\fIschema_element\fB\fR
そのスキーマ内で作成されるオブジェクトを定義するSQL文です。
現在、\fBCREATE SCHEMA\fR内では、\fBCREATE TABLE\fR、\fBCREATE VIEW\fR、\fBCREATE INDEX\fR、\fBCREATE SEQUENCE\fR、\fBCREATE TRIGGER\fR、および\fBGRANT\fRのみが句として使用可能です。
他の種類のオブジェクトは、スキーマ作成後に個別のコマンドで作成できます。
.SH "注釈"
.PP
スキーマを作成するには、呼び出すユーザが、現在のデータベースでのCREATE権限を持っている必要があります。
(もちろん、スーパーユーザにはこの制限はありません。)
.SH "例"
.PP
スキーマを作成します。
.sp
.nf
CREATE SCHEMA myschema;
.sp
.fi
.PP
joeユーザ用にスキーマを作成します。
このスキーマの名前はjoeになります。
.sp
.nf
CREATE SCHEMA AUTHORIZATION joe;
.sp
.fi
.PP
スキーマを作成し、その中にテーブルとビューを作成します。
.sp
.nf
CREATE SCHEMA hollywood
    CREATE TABLE films (title text, release date, awards text[])
    CREATE VIEW winners AS
        SELECT title, release FROM films WHERE awards IS NOT NULL;
.sp
.fi
個々のサブコマンドがセミコロンで終わっていないことに注意してください。
.PP
以下は、上と同じ結果をもたらす等価な方法です。
.sp
.nf
CREATE SCHEMA hollywood;
CREATE TABLE hollywood.films (title text, release date, awards text[]);
CREATE VIEW hollywood.winners AS
    SELECT title, release FROM hollywood.films WHERE awards IS NOT NULL;
.sp
.fi
.SH "互換性"
.PP
標準SQLでは、\fBCREATE SCHEMA\fRでDEFAULT CHARACTER SET句を使用できます。
同様に、現在PostgreSQLで使用できるよりも多くのサブコマンドを使用できます。
.PP
標準SQLでは、\fBCREATE SCHEMA\fRのサブコマンドを任意の順序で記述できます。
現在のPostgreSQLの実装では、サブコマンドでの下方参照ができない場合があります。
そのため、下方参照を避けるために、サブコマンドの順序を並べ替える必要が生じる可能性もあります。
.PP
標準SQLでは、スキーマの所有者は、常にそのスキーマ内の全てのオブジェクトを所有しています。
PostgreSQLでは、スキーマ所有者以外のユーザが所有するオブジェクトを、スキーマに含めることができます。 
このような状態は、スキーマ所有者が、自分のスキーマでのCREATE権限を他のユーザに与えた場合にのみ発生します。
.SH "関連項目"
ALTER SCHEMA [\fBalter_schema\fR(l)], DROP SCHEMA [\fBdrop_schema\fR(l)]
