.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "MOVE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
MOVE \- カーソルの位置決め

.SH SYNOPSIS
.sp
.nf
MOVE [ \fIdirection\fR { FROM | IN } ] \fIcursorname\fR
.sp
.fi
.SH "説明"
.PP
\fBMOVE\fRはデータを取り出すこと無くカーソルの位置を変更します。
\fBMOVE\fRは\fBFETCH\fRコマンドと全く同じように動作しますが、カーソルの位置を変えるだけで行を返しません。
.PP
構文と使用方法についての詳細はFETCH [\fBfetch\fR(l)]を参照してください。
.SH "出力"
.PP
正常に終了すると、\fBMOVE\fRは以下の形式のコマンドタグを返します。
.sp
.nf
MOVE \fIcount\fR
.sp
.fi
\fIcount\fRは同じパラメータを与えた\fBFETCH\fRコマンドが返すはずの行数です。
(0の場合もあります。)
.SH "例"
.sp
.nf
BEGIN WORK;
DECLARE liahona CURSOR FOR SELECT * FROM films;

-- 最初の5行を飛ばします。
MOVE FORWARD 5 IN liahona;
MOVE 5

-- liahonaカーソル内の6行目を抽出します。
FETCH 1 FROM liahona;
 code  | title  | did | date_prod  |  kind  |  len
-------+--------+-----+------------+--------+-------
 P_303 | 48 Hrs | 103 | 1982-10-22 | Action | 01:37
(1 row)

-- liahonaカーソルを閉じ、トランザクションを終了します。
CLOSE liahona;
COMMIT WORK;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBMOVE\fR文はありません。
.SH "関連項目"
CLOSE [\fBclose\fR(l)], DECLARE [\fBdeclare\fR(l)], FETCH [\fBfetch\fR(l)]
