.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP LANGUAGE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP LANGUAGE \- 手続き言語の削除

.SH SYNOPSIS
.sp
.nf
DROP [ PROCEDURAL ] LANGUAGE \fIname\fR [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP PROCEDURAL LANGUAGE\fRは\fIname\fRという名前で登録されていた手続き言語の定義を削除します。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の手続き言語の名前です。
後方互換のため、この名前を単一引用符で括ることもできます。
.TP
\fBCASCADE\fR
その言語に依存するオブジェクト(その言語で記述している関数など)を自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、その言語の削除要求を拒否します。
これがデフォルトです。
.SH "例"
.PP
このコマンドはplsample手続き言語を削除します。
.sp
.nf
DROP LANGUAGE plsample;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBDROP LANGUAGE\fR文はありません。
.SH "関連項目"
ALTER LANGUAGE [\fBalter_language\fR(l)], CREATE LANGUAGE [\fBcreate_language\fR(l)], \fBdroplang\fR(1)
