.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER SCHEMA" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER SCHEMA \- スキーマ定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER SCHEMA \fIname\fR RENAME TO \fInewname\fR
ALTER SCHEMA \fIname\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER SCHEMA\fRはスキーマ定義を変更します。
スキーマ名を変更するには、そのスキーマを所有する必要があり、また、そのデータベース上のCREATE権限が必要です。
スキーマの所有者を変更するには、スーパーユーザでなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存のスキーマの名前です。
.TP
\fB\fInewname\fB\fR
新しいスキーマ名です。
システムスキーマとして予約されていますので、この新しい名前をpg_から始めることはできません。
.TP
\fB\fInewowner\fB\fR
新しいスキーマの所有者です。
.SH "互換性"
.PP
標準SQLには\fBALTER SCHEMA\fR文はありません。
.SH "関連項目"
CREATE SCHEMA [\fBcreate_schema\fR(l)], DROP SCHEMA [\fBdrop_schema\fR(l)]
