.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_fname" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_fname \- 指定した列番号に対する列名を決定します。

.SH SYNOPSIS
.sp
.nf
char * SPI_fname(TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_fname\fR は指定した列の列名のコピーを返します。
(名前のコピーが不要になった場合\fBpfree\fRを使用してその領域を解放することができます。)
.SH "引数"
.TP
\fBTupleDesc \fIrowdesc\fB\fR
入力行の記述。
.TP
\fBint \fIcolnumber\fB\fR
(1から始まる)列番号
.SH "戻り値"
.PP
列の名前です。
\fIcolnumber\fRが範囲外の場合は\fBNULL\fRです。
エラー時、SPI_resultは\fBSPI_ERROR_NOATTRIBUTE\fRに設定されます。
