.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "COMMENT" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
COMMENT \- オブジェクトのコメントの定義、または変更

.SH SYNOPSIS
.sp
.nf
COMMENT ON
{
  TABLE \fIobject_name\fR |
  COLUMN \fItable_name\fR.\fIcolumn_name\fR |
  AGGREGATE \fIagg_name\fR (\fIagg_type\fR) |
  CAST (\fIsourcetype\fR AS \fItargettype\fR) |
  CONSTRAINT \fIconstraint_name\fR ON \fItable_name\fR |
  CONVERSION \fIobject_name\fR |
  DATABASE \fIobject_name\fR |
  DOMAIN \fIobject_name\fR |
  FUNCTION \fIfunc_name\fR (\fIarg1_type\fR, \fIarg2_type\fR, ...) |
  INDEX \fIobject_name\fR |
  LARGE OBJECT \fIlarge_object_oid\fR |
  OPERATOR \fIop\fR (\fIleftoperand_type\fR, \fIrightoperand_type\fR) |
  OPERATOR CLASS \fIobject_name\fR USING \fIindex_method\fR |
  [ PROCEDURAL ] LANGUAGE \fIobject_name\fR |
  RULE \fIrule_name\fR ON \fItable_name\fR |
  SCHEMA \fIobject_name\fR |
  SEQUENCE \fIobject_name\fR |
  TRIGGER \fItrigger_name\fR ON \fItable_name\fR |
  TYPE \fIobject_name\fR |
  VIEW \fIobject_name\fR
} IS \fI'text'\fR
.sp
.fi
.SH "説明"
.PP
\fBCOMMENT\fRは、データベースオブジェクトに関するコメントを保存します。
.PP
コメントを編集するには、同一オブジェクトに対して新しく\fBCOMMENT\fRコマンドを発行してください。
各オブジェクトに保存されるコメント文字列は1つだけです。
コメントを削除するには、NULLをテキスト文字列の部分に書いてください。
オブジェクトが削除された時、コメントは自動的に削除されます。
.PP
コメントは、\fBpsql\fRのコマンド\fB\\dd\fR、\fB\\d+\fR、\fB\\l+\fRで簡単に取り出すことができます。
\fBobj_description()\fRと\fBcol_description()\fRという名前の、\fBpsql\fRが使用している組込み関数を使用するように構築することで、他のユーザインタフェースでコメントを取り出すことができます。
(the documentationを参照してください。)
.SH "パラメータ"
.TP
\fB\fIobject_name\fB\fR
.TP
\fB\fItable_name.column_name\fB\fR
.TP
\fB\fIagg_name\fB\fR
.TP
\fB\fIconstraint_name\fB\fR
.TP
\fB\fIfunc_name\fB\fR
.TP
\fB\fIop\fB\fR
.TP
\fB\fIrule_name\fB\fR
.TP
\fB\fItrigger_name\fB\fR
コメントを付けるオブジェクトの名前です。 
テーブル、集約、ドメイン、関数、インデックス、演算子、演算子クラス、シーケンス、データ型、およびビューの名前は、スキーマ修飾することができます。
.TP
\fB\fIagg_type\fB\fR
集約関数の引数データ型です。もし、関数が任意のデータ型を受け付ける場合は*です。
.TP
\fB\fIlarge_object_oid\fB\fR
ラージオブジェクトのOIDです。
.TP
\fBPROCEDURAL\fR
この単語はノイズです。
.TP
\fB\fIsourcetype\fB\fR
キャストの変換元データ型の名前です。
.TP
\fB\fItargettype\fB\fR
キャストの変換先のデータ型の名前です。
.TP
\fB\fItext\fB\fR
文字列リテラルとして記述される、追加するコメントです。
コメントを削除する場合はNULLです。
.SH "注釈"
.PP
あるデータベースのコメントはそのデータベース内のみで作成されます。
そのため、そのデータベースからのみ可視であり、他のデータベースからは不可視です。
.PP
現在、コメントにはセキュリティ機構は存在しません。
データベースに接続したユーザは誰でも、そのデータベース内のオブジェクトのコメントを参照することができます(しかし、スーパーユーザのみが所有していないオブジェクトに関するコメントを変更することができます)。
そのため、セキュリティ的に致命的な情報をコメントに記載してはいけません。
.SH "例"
.PP
mytableテーブルにコメントを付けます。
.sp
.nf
COMMENT ON TABLE mytable IS 'This is my table.';
.sp
.fi
今度はそのコメントを削除します。
.sp
.nf
COMMENT ON TABLE mytable IS NULL;
.sp
.fi
.PP
いくつか他の例を示します。
.sp
.nf
COMMENT ON AGGREGATE my_aggregate (double precision) IS 'Computes sample variance';
COMMENT ON CAST (text AS int4) IS 'Allow casts from text to int4';
COMMENT ON COLUMN my_table.my_column IS 'Employee ID number';
COMMENT ON CONVERSION my_conv IS 'Conversion to Unicode';
COMMENT ON DATABASE my_database IS 'Development Database';
COMMENT ON DOMAIN my_domain IS 'Email Address Domain';
COMMENT ON FUNCTION my_function (timestamp) IS 'Returns Roman Numeral';
COMMENT ON INDEX my_index IS 'Enforces uniqueness on employee ID';
COMMENT ON LANGUAGE plpython IS 'Python support for stored procedures';
COMMENT ON LARGE OBJECT 346344 IS 'Planning document';
COMMENT ON OPERATOR ^ (text, text) IS 'Performs intersection of two texts';
COMMENT ON OPERATOR ^ (NONE, text) IS 'This is a prefix operator on text';
COMMENT ON OPERATOR CLASS int4ops USING btree IS '4 byte integer operators for btrees';
COMMENT ON RULE my_rule ON my_table IS 'Logs updates of employee records';
COMMENT ON SCHEMA my_schema IS 'Departmental data';
COMMENT ON SEQUENCE my_sequence IS 'Used to generate primary keys';
COMMENT ON TABLE my_schema.my_table IS 'Employee Information';
COMMENT ON TRIGGER my_trigger ON my_table IS 'Used for RI';
COMMENT ON TYPE complex IS 'Complex number data type';
COMMENT ON VIEW my_view IS 'View of departmental costs';
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBCOMMENT\fRはありません。
