.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SET CONSTRAINTS" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
SET CONSTRAINTS \- 現在のトランザクションの制約検査モードの設定

.SH SYNOPSIS
.sp
.nf
SET CONSTRAINTS { ALL | \fIname\fR [, ...] } { DEFERRED | IMMEDIATE }
.sp
.fi
.SH "説明"
.PP
\fBSET CONSTRAINTS\fRは、現在のトランザクションにおける制約の検査方法を設定します。
\fBIMMEDIATE\fR制約は、一つの文の実行が終わる毎に検査されます。
\fBDEFERRED\fR制約は、トランザクションがコミットされるまで検査されません。
各制約は個別にIMMEDIATEかDEFERREDかどちらかのモードを持ちます。
.PP
制約はその生成時において、DEFERRABLE INITIALLY DEFERRED、DEFERRABLE INITIALLY IMMEDIATE、NOT DEFERRABLEの三つのうちのいずれかの特性を持ちます。
三番目のものは、常にIMMEDIATEであり、\fBSET CONSTRAINTS\fRコマンドで有効になりません。
初めの二つは、全てのトランザクションを指定したモードで開始しますが、トランザクション内で\fBSET CONSTRAINTS\fRを使用してその振舞いを変更することができます。
.PP
制約名のリストを持った\fBSET CONSTRAINTS\fRは、それらの制約のモードのみを変更します。
（これらは全て遅延可能でなければなりません。）
指定した名前に一致する制約が複数存在した場合、その全てが影響を受けます。
\fBSET CONSTRAINTS ALL\fRは遅延可能な制約全てに対してそのモードを変更します。
.PP
制約のモードをDEFERREDからIMMEDIATEに変更した場合は、新しい制約モードが遡及的に有効になります。 
つまり(DEFERREDを使用している場合には）トランザクションの終了時に検査されることになる未検査のデータ変更が、代わりに\fBSET CONSTRAINTS\fRコマンドの実行中に検査されます。
もし、この時に何らかの制約違反があった場合、\fBSET CONSTRAINTS\fRは失敗します。
（そして、制約モードは変更されません。）
従って、\fBSET CONSTRAINTS\fRを使用して、トランザクションの特定の時点で制約の検査を強制的に実行することができます。
.PP
今のところ、外部キーの制約だけがこの設定の影響を受けます。
検査制約や一意性制約は、常に遅延されません。
.SH "注釈"
.PP
このコマンドは、現在のトランザクション内のみの制約の動作を変更します。
したがって、トランザクションブロック(\fBBEGIN\fR/\fBCOMMIT\fRの間)の外部でこのコマンドを実行した場合、全く影響を与えません。
.SH "互換性"
.PP
このコマンドは、標準SQLで定義された動作に準拠しています。
ただし、PostgreSQLでは外部キー制約にのみ適用できるという制限があります。
.PP
標準SQLでは、\fBSET CONSTRAINTS\fR内の制約名はスキーマで修飾できるものとしています。
これはまだPostgreSQLではサポートされていません。
この名前は未修飾でなければならず、制約が存在するスキーマに関係なく、コマンドで指定したものと一致する全ての制約が影響を受けます。
