.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER LANGUAGE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER LANGUAGE \- 手続き言語の定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER LANGUAGE \fIname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER LANGUAGE\fRは、言語の定義を変更します。
唯一の機能は言語名の変更です。
スーパーユーザのみが言語名を変更することができます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
言語の名前です。
.TP
\fB\fInewname\fB\fR
新しい言語の名前です。
.SH "互換性"
.PP
標準SQLには\fBALTER LANGUAGE\fR文はありません。
.SH "関連項目"
CREATE LANGUAGE [\fBcreate_language\fR(l)], DROP LANGUAGE [\fBdrop_language\fR(l)]
