.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_pop" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_pop \- 再帰的なSPIの使用から復帰できるようにSPIスタックをポップします。

.SH SYNOPSIS
.sp
.nf
void SPI_pop(void)
.sp
.fi
.SH "説明"
.PP
\fBSPI_pop\fRは、SPI呼び出しスタックから以前の環境をポップします。
\fBSPI_push\fRを参照してください。
