.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CLOSE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CLOSE \- カーソルを閉じる

.SH SYNOPSIS
.sp
.nf
CLOSE \fIname\fR
.sp
.fi
.SH "説明"
.PP
\fBCLOSE\fRは開いたカーソルに関連するリソースを解放します。
カーソルが閉じられた後は、そのカーソルに対する操作はできません。
カーソルは必要がなくなったときに閉じるべきです。
.PP
トランザクションが\fBCOMMIT\fRもしくは\fBROLLBACK\fRで終了された時点で、開いている保持不可能カーソルは全て暗黙的に閉ざされます。
\fBROLLBACK\fRにより、保持可能カーソルを作成したトランザクションをアボートした場合、保持可能カーソルは暗黙的に閉ざされます。
作成したトランザクションが正常にコミットされた場合、保持可能カーソルは明示的な\fBCLOSE\fRが実行されるまで、あるいは、クライアントとの接続が切断されるまで、開いたままです。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
閉じる対象の、現在開いているカーソルの名前です。
.SH "注釈"
.PP
PostgreSQLには明示的な\fBOPEN\fRカーソル文がありません。
カーソルは宣言されたときに開いているとみなれます。
カーソルの宣言にはDECLARE [\fBdeclare\fR(l)]文を使用してください。
.SH "例"
.PP
liahonaカーソルを閉じます。
.sp
.nf
CLOSE liahona;
.sp
.fi
.SH "互換性"
.PP
\fBCLOSE\fRは標準SQLと完全に互換性があります。
.SH "関連項目"
DECLARE [\fBdeclare\fR(l)], FETCH [\fBfetch\fR(l)], MOVE [\fBmove\fR(l)]
