.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE USER" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE USER \- 新しいデータベースユーザアカウントの定義

.SH SYNOPSIS
.sp
.nf
CREATE USER \fIname\fR [ [ WITH ] \fIoption\fR [ ... ] ]

ここで\fIoption\fRは以下の通りです。
    
    
      SYSID \fIuid\fR 
    | CREATEDB | NOCREATEDB
    | CREATEUSER | NOCREATEUSER
    | IN GROUP \fIgroupname\fR [, ...]
    | [ ENCRYPTED | UNENCRYPTED ] PASSWORD '\fIpassword\fR'
    | VALID UNTIL '\fIabstime\fR' 
.sp
.fi
.SH "説明"
.PP
\fBCREATE USER\fRは、PostgreSQLクラスタに新しいユーザを加えます。
ユーザの管理と認証に関する情報については、the documentationとthe documentationを参照してください。
このコマンドを使用するにはデータベースのスーパーユーザでなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
新しいユーザの名前です。
.TP
\fB\fIuid\fB\fR
SYSID句を使用して、新しいユーザのPostgreSQLユーザIDを選択することができます。
これは通常必要ありませんが、所有者がいなくなったオブジェクトの所有者を再作成しなければならない場合に有用になるかもしれません。

この句が指定されない場合、割り当て済みのユーザIDの最大値に1を足したものがデフォルトとして使われます(100 が最小値です)。
.TP
\fBCREATEDB\fR
.TP
\fBNOCREATEDB\fR
これらの句はユーザのデータベースの作成に関する権限を定義します。
CREATEDBが指定された場合、そのユーザは、自己所有のデータベースを作成することができます。
NOCREATEDBを使用した場合、作成されるユーザには、データベースを作成する権限が与えられません。
指定されなかった場合は、NOCREATEDBがデフォルトとして使用されます。
.TP
\fBCREATEUSER\fR
.TP
\fBNOCREATEUSER\fR
これらの句は、ユーザが自分で新しいユーザを作成できるかどうかを決定します。
また、CREATEにより、そのユーザは全てのアクセス制限を上書きできるスーパーユーザになります。
指定されなかった場合、ユーザの属性にはNOCREATEUSERが設定されます。
.TP
\fB\fIgroupname\fB\fR
新しいメンバとしてユーザを挿入する既存のグループの名前です。
複数のグループ名を指定することができます。
.TP
\fB\fIpassword\fB\fR
ユーザのパスワードを設定します。
もしパスワード認証を使う予定がなければこのオプションは省略できます。
しかし、パスワード認証を行うよう変更した場合このユーザは接続できません。
ALTER USER [\fBalter_user\fR(l)]を使用して、後でパスワードを設定することも変更することも可能です。
.TP
\fBENCRYPTED\fR
.TP
\fBUNENCRYPTED\fR
これらのキーワードを使用すると、パスワードを暗号化してシステムカタログに格納するかどうかを制御できます。
(どちらも設定されていない場合のデフォルトの動作は、password_encryption設定パラメータによって決まります。) 
指定された文字列がすでにMD5暗号化書式である場合は、ENCRYPTED、UNENCRYPTEDのどちらが指定されているかに関係なく、そのまま保存されます。
(システムでは、指定された暗号化されたパスワードを復号できないからです。)
これにより、ダンプ/リストアの時に暗号化パスワードを再読み込みすることができます。

古めのクライアントでは、暗号化して保存されたパスワードを使用するために必要なMD5認証機構をサポートしていない場合があることに注意してください。
.TP
\fB\fIabstime\fB\fR
VALID UNTIL句は、ユーザのパスワードが有効でなくなるまでの絶対日時を設定します。
この句が省略された場合、パスワードは永遠に有効になります。
.SH "注釈"
.PP
ユーザの属性を変更するにはALTER USER [\fBalter_user\fR(l)]を、ユーザを削除するにはDROP USER [\fBdrop_user\fR(l)]を使用してください。
ユーザをグループに追加したり、グループから削除したりするには、ALTER GROUP [\fBalter_group\fR(l)]を使用してください。 
.PP
PostgreSQLには、\fBCREATE USER\fRと同じ機能を持つ(実際にこのコマンドを呼び出しています)createuser [\fBcreateuser\fR(1)]プログラムがあり、コマンドシェルから実行することができます。
.PP
VALID UNTIL句は、パスワードのみの有効期限を定義します。
いうまでもありませんが、ユーザアカウントの有効期限ではありません。
特に、パスワードを元にしない認証方式でログインを行う場合には、この有効期限は強制されません。
.SH "例"
.PP
パスワードを持たないユーザを作成します。
.sp
.nf
CREATE USER jonathan;
.sp
.fi
.PP
パスワードを持つユーザを作成します。
.sp
.nf
CREATE USER davide WITH PASSWORD 'jw8s0F4';
.sp
.fi
.PP
アカウントが2004年の終わりまで有効なパスワードを持つユーザを作成しています。
2005年に一秒でも入った後はパスワードは無効になります。
.sp
.nf
CREATE USER miriam WITH PASSWORD 'jw8s0F4' VALID UNTIL '2005-01-01';
.sp
.fi
.PP
データベースを作成することのできるアカウントを作成します。
.sp
.nf
CREATE USER manuel WITH PASSWORD 'jw8s0F4' CREATEDB;
.sp
.fi
.SH "互換性"
.PP
\fBCREATE USER\fR文は、PostgreSQLの拡張です。
標準SQLでは、ユーザの定義は実装に任されています。
.SH "関連項目"
ALTER USER [\fBalter_user\fR(l)], DROP USER [\fBdrop_user\fR(l)], \fBcreateuser\fR(1)
