.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP CAST" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP CAST \- キャストの削除

.SH SYNOPSIS
.sp
.nf
DROP CAST (\fIsourcetype\fR AS \fItargettype\fR) [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP CAST\fRは、以前に定義したキャストを削除します。
.PP
キャストを削除可能にするには、変換元または変換先のデータ型を所有している必要があります。
これらは、キャストを作成するために必要な権限と同じです。
.SH "パラメータ"
.TP
\fB\fIsourcetype\fB\fR
キャストする変換元のデータ型の名前です。
.TP
\fB\fItargettype\fB\fR
キャストする変換先のデータ型の名前です。
.TP
\fBCASCADE\fR
.TP
\fBRESTRICT\fR
これらのキーワードを指定しても、キャストに対する依存関係がないため、効果はありません。
.SH "例"
.PP
\fBtext\fR型から\fBint\fR型へのキャストを削除します。
.sp
.nf
DROP CAST (text AS int);
.sp
.fi
.SH "互換性"
.PP
\fBDROP CAST\fRコマンドは、標準SQLに準拠しています。
.SH "関連項目"
CREATE CAST [\fBcreate_cast\fR(l)]
