.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_pfree" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_pfree \- 上位エクゼキュータコンテキスト内のメモリを解放します。

.SH SYNOPSIS
.sp
.nf
void SPI_pfree(void * \fIpointer\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_pfree\fRは、以前に\fBSPI_palloc\fR や \fBSPI_repalloc\fRを使用して割り当てられたメモリを解放します。
.PP
この関数はもはや通常の\fBpfree\fRとは異なるものではありません。
単に既存コードの後方互換性のために保持されています。
.SH "引数"
.TP
\fBvoid * \fIpointer\fB\fR
解放する既存の領域へのポインタ。
