.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_execp" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_execp \- 読み書きモードで計画を実行します。

.SH SYNOPSIS
.sp
.nf
int SPI_execp(void * \fIplan\fR, Datum * \fIvalues\fR, const char * \fInulls\fR, int \fIcount\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_execp\fRは、常に\fIread_only\fRパラメータをfalseとした\fBSPI_execute_plan\fRと同じです。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
（\fBSPI_prepare\fRで返される）実行計画
.TP
\fBDatum * \fIvalues\fB\fR
実パラメータ値の配列。
計画の引数の数と同じ長さでなければなりません。
.TP
\fBconst char * \fInulls\fB\fR
どのパラメータがNULLであるかを示す配列。
計画の引数の数と同じ長さでなければなりません。
nはNULL値を表します。(\fIvalues\fR内の項目は無視されます。)
空白は非NULLの値を表します。(\fIvalues\fR内の項目は有効です。)

\fInulls\fRが\fBNULL\fRの場合、\fBSPI_execp\fRは全てのパラメータがNULLではないとみなします。
.TP
\fBint \fIcount\fB\fR
処理される、もしくは、返される行の最大値
.SH "戻り値"
.PP
\fBSPI_execute_plan\fRを参照してください。
.PP
成功時、\fBSPI_execute\fR同様にSPI_processedとSPI_tuptableが設定されます。
