.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_cursor_fetch" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_cursor_fetch \- カーソルから数行を取り出します。

.SH SYNOPSIS
.sp
.nf
void SPI_cursor_fetch(Portal \fIportal\fR, bool \fIforward\fR, int \fIcount\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_cursor_fetch\fR はカーソルから数行を取り出します。
これは、\fBFETCH\fR SQLコマンドと等価です。
.SH "引数"
.TP
\fBPortal \fIportal\fB\fR
カーソルを持つポータル。
.TP
\fBbool \fIforward\fB\fR
前方方向の取り出しの場合、真。後方方向の場合は偽。
.TP
\fBint \fIcount\fB\fR
取り出す最大行数。
.SH "戻り値"
.PP
成功時、SPI_processed と SPI_tuptable が \fBSPI_execute\fR 同様に設定されます。
