.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP VIEW" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP VIEW \- ビューの削除

.SH SYNOPSIS
.sp
.nf
DROP VIEW \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP VIEW\fRは既存のビューを削除します。
このコマンドを実行するには、ビューの所有者でなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するビューの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
削除するビューに依存しているオブジェクト (他のビューなど) を自動的に削除します。
.TP
\fBRESTRICT\fR
依存するオブジェクトがある場合に、そのビューの削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
下記のコマンドはkindsという名前のビューを削除します。
.sp
.nf
DROP VIEW kinds;
.sp
.fi
.SH "互換性"
.PP
このコマンドは、標準では1コマンドで1つのビューのみを削除できるという点を除き、標準SQLに従っています。
.SH "関連項目"
CREATE VIEW [\fBcreate_view\fR(l)]
