.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ROLLBACK" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ROLLBACK \- 現在のトランザクションのアボート

.SH SYNOPSIS
.sp
.nf
ROLLBACK [ WORK | TRANSACTION ]
.sp
.fi
.SH "説明"
.PP
\fBROLLBACK\fRは現在のトランザクションをロールバックし、そのトランザクションで行われた全ての更新を廃棄させます。
.SH "パラメータ"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワードです。
これらは意味がありません。
.SH "注釈"
.PP
トランザクションをきちんと終了させるにはCOMMIT [\fBcommit\fR(l)]を使用してください。
.PP
トランザクションの外部で\fBROLLBACK\fRを発行しても害はありません。
しかし、警告メッセージが表示されます。
.SH "例"
.PP
全ての変更をアボートします。
.sp
.nf
ROLLBACK;
.sp
.fi
.SH "互換性"
.PP
標準SQLでは、ROLLBACKとROLLBACK WORKの2形式のみが仕様に記載されています。
この点以外は完全に互換性があります。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], ROLLBACK TO SAVEPOINT [\fBrollback_to_savepoint\fR(l)]
