.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER DATABASE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER DATABASE \- データベースの変更

.SH SYNOPSIS
.sp
.nf
ALTER DATABASE \fIname\fR SET \fIparameter\fR { TO | = } { \fIvalue\fR | DEFAULT }
ALTER DATABASE \fIname\fR RESET \fIparameter\fR

ALTER DATABASE \fIname\fR RENAME TO \fInewname\fR
ALTER DATABASE \fIname\fR OWNER TO \fInew_owner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER DATABASE\fRはデータベースの属性を変更します。
.PP
最初の2形式を使用して、PostgreSQLデータベースにおける実行時設定変数のセッションのデフォルト値を変更できます。 
指定された値が、コマンド実行後にデータベースで開始される新規セッションのデフォルト値になります。 
データベースで指定されるデフォルト値により、\fIpostgresql.conf\fRファイルに記述されている設定や\fBpostmaster\fRから受け取った設定が上書きされます。
データベースの所有者またはスーパーユーザのみが、そのデータベースのセッションのデフォルト値を変更することができます。
特定の変数についてはこの方法では設定できず、スーパーユーザのみが設定することができます。
.PP
3番目の形式では、データベースの名前を変更することができます。
データベースの所有者またはスーパーユーザのみがデータベース名を変更できます。
ただしスーパーユーザ以外の所有者はCREATEDB権限を所有していなければなりません。
現在のデータベースの名前を変更することはできません。
(必要ならば、別のデータベースに接続してください。)
.PP
4番目の形式では、データベースの所有者を変更することができます。
スーパーユーザのみがデータベースの所有者を変更することができます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
属性変更の対象となるデータベースの名前です。
.TP
\fB\fIparameter\fB\fR
.TP
\fB\fIvalue\fB\fR
指定した設定パラメータについて、このデータベースのセッションのデフォルト値を、指定した値に設定します。 
\fIvalue\fRがDEFAULTの場合、あるいは 等価なRESETが使用されている場合、データベース固有の設定は無効になり、新しいセッションではシステム全体のデフォルト設定が継承されます。 
全てのデータベース固有の設定をクリアするには、RESET ALLを使用してください。

使用可能なパラメータ名および値についての詳細は、SET [\fBset\fR(l)]およびthe documentationを参照してください。
.TP
\fB\fInewname\fB\fR
新しいデータベース名です。
.TP
\fB\fInew_owner\fB\fR
新しいデータベースの所有者です。
.SH "注釈"
.PP
データベースではなく特定のユーザにセッションのデフォルト値を関連付けることもできます。
ALTER USER [\fBalter_user\fR(l)]を参照してください
競合する場合には、ユーザ固有の設定により、データベース固有の設定が上書きされます。
.SH "例"
.PP
testデータベース内のインデックススキャンをデフォルトで無効にします。
.sp
.nf
ALTER DATABASE test SET enable_indexscan TO off;
.sp
.fi
.SH "互換性"
.PP
\fBALTER DATABASE\fR文はPostgreSQLの拡張です。
.SH "関連項目"
CREATE DATABASE [\fBcreate_database\fR(l)], DROP DATABASE [\fBdrop_database\fR(l)], SET [\fBset\fR(l)]
