.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_gettypeid" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_gettypeid \- 指定された列のデータ型のOID を返します。

.SH SYNOPSIS
.sp
.nf
Oid SPI_gettypeid(TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_gettypeid\fR は指定された列のデータ型のOID を返します。
.SH "引数"
.TP
\fBTupleDesc \fIrowdesc\fB\fR
入力行の記述。
.TP
\fBint \fIcolnumber\fB\fR
(1から始まる)行番号。
.SH "戻り値"
.PP
指定された列のデータ型のOIDです。
エラー時は\fBInvalidOid\fRです。
エラー時、SPI_result は\fBSPI_ERROR_NOATTRIBUTE\fRに設定されます。
