.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DEALLOCATE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DEALLOCATE \- 準備された文の割り当て解除

.SH SYNOPSIS
.sp
.nf
DEALLOCATE [ PREPARE ] \fIplan_name\fR
.sp
.fi
.SH "説明"
.PP
\fBDEALLOCATE\fRを使用して、過去に準備されたSQL文の割り当てを解除します。
準備された文を明示的に割り当て解除しなかった場合、セッションが終了した時に割り当てが解除されます。
.PP
準備された文に関するより詳細についてはPREPARE [\fBprepare\fR(l)]を参照してください。
.SH "パラメータ"
.TP
\fBPREPARE\fR
このキーワードは無視されます。
.TP
\fB\fIplan_name\fB\fR
割り当てを解除する、準備された文の名前です。
.SH "互換性"
.PP
\fBDEALLOCATE\fR文は標準SQLにありますが、埋め込みSQLでの使用のみに限られています。
.SH "関連項目"
EXECUTE [\fBexecute\fR(l)], PREPARE [\fBprepare\fR(l)]
