.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_is_cursor_plan" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_is_cursor_plan \- SPI_prepareで準備された計画がSPI_cursor_openで使用できる場合にtrueを返します。

.SH SYNOPSIS
.sp
.nf
bool SPI_is_cursor_plan(void * \fIplan\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_prepare\fRで準備された計画が\fBSPI_cursor_open\fRへの引数として渡すことができる場合、\fBSPI_is_cursor_plan\fRは\fBtrue\fRを返します。
渡すことができない場合は\fBfalse\fRを返します。
この基準は、\fIplan\fRが単一のコマンドであり、かつ、そのコマンドが\fBINTO\fR句のない\fBSELECT\fRであることです。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
（\fBSPI_prepare\fRで返される）実行計画です。
.SH "戻り値"
.PP
\fIplan\fRがカーソルを生成することができるかどうかを示す\fBtrue\fRもしくは \fBfalse\fRです。
\fIplan\fRが\fBNULL\fRの場合は\fBSPI_ERROR_ARGUMENT\fRが返ります。
