.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE SEQUENCE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE SEQUENCE \- 新しいシーケンス生成器の定義

.SH SYNOPSIS
.sp
.nf
CREATE [ TEMPORARY | TEMP ] SEQUENCE \fIname\fR [ INCREMENT [ BY ] \fIincrement\fR ]
    [ MINVALUE \fIminvalue\fR | NO MINVALUE ] [ MAXVALUE \fImaxvalue\fR | NO MAXVALUE ]
    [ START [ WITH ] \fIstart\fR ] [ CACHE \fIcache\fR ] [ [ NO ] CYCLE ]
.sp
.fi
.SH "説明"
.PP
\fBCREATE SEQUENCE\fRは、新しいシーケンス番号生成機構を作成します。
これは、\fIname\fRという名前を持った一行だけの新しい特殊なテーブルの作成と初期化を行います。
シーケンス番号生成機構は、このコマンドを実行したユーザによって所有されます。
.PP
スキーマ名が与えられている場合、そのシーケンスは指定されたスキーマで作成されます。
スキーマ名がなければ、シーケンスは現在のスキーマで作成されます。
また、一時シーケンスは特別なスキーマに存在するため、一時シーケンスの作成時にスキーマ名を与えることはできません。
シーケンス名は、同じスキーマ内の他のシーケンス、テーブル、インデックス、もしくはビューとは異なる名前にする必要があります。
.PP
シーケンスを作成した後、\fBnextval\fR、\fBcurrval\fR、\fBsetval\fR関数を使用してシーケンスを操作します。
この関数はthe documentationで説明されています。
.PP
シーケンスを直接更新することはできませんが、以下のような問い合わせを使用できます。
.sp
.nf
SELECT * FROM \fIname\fR;
.sp
.fi
これを使用すると、シーケンスのパラメータと現在の状態を確認することができます。
特に、シーケンスのlast_valueフィールドは全てのセッションで割り当てられた最後の値を示します。
(もちろん、この値は表示された時点で、他のセッションの\fBnextval\fRの実行により古くなっている場合もあります。)
.SH "パラメータ"
.TP
\fBTEMPORARYもしくはTEMP\fR
指定された場合、このシーケンスオブジェクトはそのセッション用だけとして作成され、セッション終了時に自動的に削除されます。
一時シーケンスが存在する場合、同じ名前を持つ既存の永続シーケンスはスキーマ修飾された名前で参照されていなければ、(そのセッションでは)非可視です。
.TP
\fB\fIname\fB\fR
作成するシーケンスの名前です (スキーマ修飾名でも可)。
.TP
\fB\fIincrement\fB\fR
省略可能なINCREMENT BY \fIincrement\fR句は、現在のシーケンスの値から新しい値を作成する時に足し込まれる増加量を設定します。
正の値は昇順のシーケンス、負の値は降順のシーケンスを作成します。
設定しない場合のデフォルト値は1です。
.TP
\fB\fIminvalue\fB\fR
.TP
\fBNO MINVALUE\fR
省略可能なMINVALUE \fIminvalue\fR句は、シーケンスとして作成できる最小の値を決定します。
この句の指定がない、もしくは、\fBNO MINVALUE\fRが指定された場合、デフォルトが使用されます。
昇順と降順のシーケンスのデフォルト値は、それぞれ1と-(263-1)です。
.TP
\fB\fImaxvalue\fB\fR
.TP
\fBNO MAXVALUE\fR
省略可能なMAXVALUE \fImaxvalue\fR句は、シーケンスの最大値を決定します。
この句の指定がない、もしくは、\fBNO MAXVALUE\fRが指定された場合、デフォルトが使用されます。
昇順と降順のそれぞれのシーケンス番号の最大値のデフォルトは、263-1と-1です。
.TP
\fB\fIstart\fB\fR
省略可能なSTART WITH \fIstart\fR句によって、シーケンスをどこからでも始めることができます。
デフォルトでは、シーケンス番号が始まる値は、昇順の場合\fIminvalue\fRに、降順の場合\fImaxvalue\fRになります。
.TP
\fB\fIcache\fB\fR
CACHE \fIcache\fRオプションは、どのくらいの数のシーケンス番号をあらかじめ番号を割り当て、メモリに格納するかを指定します。これによりアクセスを高速にすることができます。
最小値は1（これは1回につき1つの値だけを生成します。つまりキャッシュはありません）で、これがデフォルトにもなっています。
.TP
\fBCYCLE\fR
.TP
\fBNO CYCLE\fR
CYCLEオプションによって、昇順、あるいは降順のシーケンス番号が、それぞれ\fImaxvalue\fRまたは\fIminvalue\fRの値に達した時に、シーケンスを元に戻すことができます。
もしシーケンス番号の限界値まで達した場合、次に生成される番号は\fIminvalue\fRまたは\fImaxvalue\fRのどちらかになります。

NO CYCLEが指定された場合、制限に達した後の\fBnextval\fR呼び出しはエラーになります。
CYCLEもNO CYCLEも指定されない場合は、NO CYCLEがデフォルトです。
.SH "注釈"
.PP
シーケンスを削除するには\fBDROP SEQUENCE\fRを使用してください。
.PP
シーケンスは\fBbigint\fR算術に基づいています。
そのため、8バイト整数の範囲(-9223372036854775808から9223372036854775807まで)を越えることはできません。
古めのプラットフォームでは、8バイト整数をサポートするコンパイラがないことがあります。
その場合、シーケンスは通常の\fBinteger\fR算術を使用します。(その範囲は-2147483648から+2147483647までです。)
.PP
1より大きな値に設定された\fIcache\fRがシーケンスオブジェクトで使用された場合、そのシーケンスを複数のセッションで同時に使用した場合に予想外の結果になる場合があります。
各セッションは、セッションがシーケンスオブジェクトにアクセスすると、連続するシーケンス値を割り当てキャッシュします。
そして、それに伴い、シーケンスオブジェクトのlast_valueは増加します。
これにより、そのセッション内におけるその後の\fIcache\fR-1回の使用では、割り当て済みの値を単に返し、シーケンスオブジェクトは変更されません。
セッションにおいて割り当てられたが使用されなかった番号は、セッションの終了時に全て失われますので、結果としてシーケンスに``穴''ができます。
.PP
更に、複数のセッションには個別のシーケンス値が割り当てられることが保証されていますが、全てのセッションが尊重されると、シーケンスの値は順番通りにならないことがあります。
例えば、\fIcache\fRが10の場合を考えます。
セッションAでは1から10までを確保し、\fBnextval\fR=1を返します。
セッションBでは、セッションAが\fBnextval\fR=2を返す前に、11から20を確保し、\fBnextval\fR=11を返します。
従って、\fIcache\fRを1に設定した場合は\fBnextval\fRが連続した値を生成することを前提としても問題ありませんが、1より大きな値の\fIcache\fRが設定されると、\fBnextval\fRの値が本当に連続しているのではなく、全く異なる値となるということしか前提とすることができません。
また、last_valueは、その値が\fBnextval\fRで返されたかどうかに関係なく、全てのセッションで確保された最後の値を反映します。
.PP
この他、そういったシーケンスに対して実行される\fBsetval\fRは他のセッションでは、キャッシュした割り当て済の値を全て使い果たすまで、分からないということも考慮すべきです。
.SH "例"
.PP
101から始まるserialという名前の昇順シーケンスを作成します。
.sp
.nf
CREATE SEQUENCE serial START 101;
.sp
.fi
.PP
このシーケンスから次の番号を選択します。
.sp
.nf
SELECT nextval('serial');
    
 nextval
---------
     114
.sp
.fi
.PP
このシーケンスを\fBINSERT\fRコマンドで使用します。
.sp
.nf
INSERT INTO distributors VALUES (nextval('serial'), 'nothing');
.sp
.fi
.PP
\fBCOPY FROM\fRの後でシーケンス値を更新します。
.sp
.nf
BEGIN;
COPY distributors FROM 'input_file';
SELECT setval('serial', max(id)) FROM distributors;
END;
.sp
.fi
.SH "互換性"
.PP
\fBCREATE SEQUENCE\fRはSQL:2003で規定されています。
PostgreSQLは、以下の例外を除き、この標準に従います。
.TP 0.2i
\(bu
標準におけるAS <data type>式はサポートされていません。
.TP 0.2i
\(bu
次の値を取り出すには、標準の\fBNEXT VALUE FOR\fR式ではなく\fBnextval()\fR関数を使用します。
.PP
