.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "UNLISTEN" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
UNLISTEN \- 通知の監視の停止

.SH SYNOPSIS
.sp
.nf
UNLISTEN { \fIname\fR | * }
.sp
.fi
.SH "説明"
.PP
\fBUNLISTEN\fRを使用して、既存の\fBNOTIFY\fRイベントの登録を削除します。
\fBUNLISTEN\fRは現在のPostgreSQLセッションにある、\fIname\fR通知条件用のリスナ登録を全て取り消します。
ワイルドカード*は特別な条件を示すもので、現在のセッションにある全てのリスナ登録を取り消します。
.PP
NOTIFY [\fBnotify\fR(l)]には、\fBLISTEN\fRと\fBNOTIFY\fRについてのより広範な説明があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
通知名です。(任意の識別子です。)
.TP
\fB*\fR
このセッションにおける、全ての監視登録をクリアします。
.SH "注釈"
.PP
監視を全く行っていない状態でもこのコマンドを実行できます。警告やエラーは表示されません。
.PP
セッション終了時に、自動的に\fBUNLISTEN *\fRが実行されます。
.SH "例"
.PP
登録を行います。
.sp
.nf
LISTEN virtual;
NOTIFY virtual;
Asynchronous notification "virtual" received from server process with PID 8448.
.sp
.fi
.PP
\fBUNLISTEN\fRが実行されると、その後の\fBNOTIFY\fRコマンドは無視されます。
.sp
.nf
UNLISTEN virtual;
NOTIFY virtual;
-- NOTIFY イベントを受け取りません。
.sp
.fi
.SH "互換性"
.PP
標準SQLには \fBUNLISTEN\fR コマンドはありません。
.SH "関連項目"
LISTEN [\fBlisten\fR(l)], NOTIFY [\fBnotify\fR(l)]
