.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SAVEPOINT" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
SAVEPOINT \- 現在のトランザクション内にセーブポイントを新規に定義

.SH SYNOPSIS
.sp
.nf
SAVEPOINT \fIsavepoint_name\fR
.sp
.fi
.SH "説明"
.PP
\fBSAVEPOINT\fRは、現在のトランザクション内に新しいセーブポイントを確立します。
.PP
セーブポイントとはトランザクション内の特別な印で、確立後に実行されたコマンドを全てロールバックし、セーブポイントの時点の状態にトランザクションを戻すことができます。
.SH "パラメータ"
.TP
\fB\fIsavepoint_name\fB\fR
新しいセーブポイントに付与する名前です。
.SH "注釈"
.PP
セーブポイントまでロールバックするにはROLLBACK TO SAVEPOINT [\fBrollback_to_savepoint\fR(l)]を使用してください。
確立後に行われたコマンドの効果を保持したままセーブポイントを破棄するには、RELEASE SAVEPOINT [\fBrelease_savepoint\fR(l)]を使用してください。
.PP
セーブポイントはトランザクションブロックの内側でのみ確立することができます。
1つのトランザクションの中で複数のセーブポイントを定義することができます。
.SH "例"
.PP
セーブポイントを確立し、その後に確立後に実行した全てのコマンドの効果を取消します。
.sp
.nf
BEGIN;
    INSERT INTO table1 VALUES (1);
    SAVEPOINT my_savepoint;
    INSERT INTO table1 VALUES (2);
    ROLLBACK TO SAVEPOINT my_savepoint;
    INSERT INTO table1 VALUES (3);
COMMIT;
.sp
.fi
上のトランザクションでは、1と3は挿入されますが、2は挿入されません。
.PP
セーブポイントを確立し、その後に破棄します。
.sp
.nf
BEGIN;
    INSERT INTO table1 VALUES (3);
    SAVEPOINT my_savepoint;
    INSERT INTO table1 VALUES (4);
    RELEASE SAVEPOINT my_savepoint;
COMMIT;
.sp
.fi
上のトランザクションでは、3と4が挿入されます。
.SH "互換性"
.PP
SQLでは、同じ名前のセーブポイントが確立したときに自動的にセーブポイントを破棄することを要求しています。
PostgreSQLでは、古いセーブポイントは保持されます。
しかし、ロールバックや解放時にはより最近のセーブポイントが使用されます。
（より新しいセーブポイントを解放することで、古い方が再び\fBROLLBACK TO SAVEPOINT\fRと\fBRELEASE SAVEPOINT\fRから使用できるようになります。）
この他については\fBSAVEPOINT\fRは完全にSQLに従います。
.SH "関連項目"
BEGIN [\fBbegin\fR(l)], COMMIT [\fBcommit\fR(l)], RELEASE SAVEPOINT [\fBrelease_savepoint\fR(l)], ROLLBACK [\fBrollback\fR(l)], ROLLBACK TO SAVEPOINT [\fBrollback_to_savepoint\fR(l)]
