.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_push" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_push \- 再帰的にSPIを使用できるようにSPIスタックをプッシュします。

.SH SYNOPSIS
.sp
.nf
void SPI_push(void)
.sp
.fi
.SH "説明"
.PP
\fBSPI_push\fRは、それ自体がSPIを使用する可能性がある他のプロシージャを実行する前に呼び出されなければなりません。
\fBSPI_push\fRの後、SPIは``接続''状態ではなくなります。
新しく\fBSPI_connect\fRを実行しない限り、SPI関数の呼び出しは拒絶されます。
これにより確実にプロシージャのSPI状態と呼び出した別のプロシージャのSPI状態を明確に分離できます。
他のプロシージャから復帰した後に\fBSPI_pop\fRを呼び出して、そのプロシージャのSPI状態にアクセスを戻してください。
.PP
\fBSPI_execute\fRとその関連関数は、制御をSQL実行エンジンに戻す前に自動的に\fBSPI_push\fR同等の処理を行うことに注意してください。
ですので、こうした関数を使用する際には気にする必要はありません。
\fBSPI_connect\fR呼び出しを行う可能性がある任意のコードを直接呼び出す場合のみ、\fBSPI_push\fRと\fBSPI_pop\fRを呼び出さなければなりません。
