.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_returntuple" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_returntuple \- Datumとしてタプルを返す準備をします。

.SH SYNOPSIS
.sp
.nf
HeapTupleHeader SPI_returntuple(HeapTuple \fIrow\fR, TupleDesc \fIrowdesc\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_returntuple\fRは上位エクゼキュータコンテキスト内に行の複製を作成し、それを行型の\fBDatum\fR形式で返します。
返されるポインタは、返す前に\fBPointerGetDatum\fRを使用して\fBDatum\fRに変換することのみが必要です。
.PP
この関数は複合型を返すものと宣言された関数に対して使用しなければなりません。
トリガでは使用されません。
トリガで変更された行を返すには\fBSPI_copytuple\fRを使用してください。
.SH "引数"
.TP
\fBHeapTuple \fIrow\fB\fR
複製される行です。
.TP
\fBTupleDesc \fIrowdesc\fB\fR
行の記述子です。
（最も効率的にキャッシュを行えるように毎回同一の記述子を渡してください。）
.SH "戻り値"
.PP
複製された行を指し示す\fBHeapTupleHeader\fRです。
\fIrow\fR もしくは\fIrowdesc\fRが\fBNULL\fRの場合のみ\fBNULL\fRが返ります。
