.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER CONVERSION" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER CONVERSION \- 変換定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER CONVERSION \fIname\fR RENAME TO \fInewname\fR
ALTER CONVERSION \fIname\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER CONVERSION\fRは変換の定義を変更します。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の変換の名前です。(スキーマ修飾名も可。)
.TP
\fB\fInewname\fB\fR
新しい変換の名前です。
.TP
\fB\fInewowner\fB\fR
新しい変換の所有者です。
変換の所有者を変更するにはスーパーユーザでなければなりません。
.SH "例"
.PP
iso_8859_1_to_utf_8変換の名前をlatin1_to_unicodeへ変更します。
.sp
.nf
ALTER CONVERSION iso_8859_1_to_utf_8 RENAME TO latin1_to_unicode;
.sp
.fi
.PP
iso_8859_1_to_utf_8変換の所有者をjoeに変更します。
.sp
.nf
ALTER CONVERSION iso_8859_1_to_utf_8 OWNER TO joe;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER CONVERSION\fR文はありません。
.SH "関連項目"
CREATE CONVERSION [\fBcreate_conversion\fR(l)], DROP CONVERSION [\fBdrop_conversion\fR(l)]
