.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP INDEX" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP INDEX \- インデックスの削除

.SH SYNOPSIS
.sp
.nf
DROP INDEX \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP INDEX\fRはデータベースシステムから既存のインデックスを削除します。
このコマンドを実行するには、そのインデックスを所有している必要があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
削除するインデックスの名前です (スキーマ修飾名でも可)。
.TP
\fBCASCADE\fR
そのインデックスに依存しているオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、そのインデックスの削除要求を拒否します。
これがデフォルトです。
.SH "例"
.PP
このコマンドはtitle_idxインデックスを削除します。
.sp
.nf
DROP INDEX title_idx;
.sp
.fi
.SH "互換性"
.PP
\fBDROP INDEX\fRはPostgreSQLの言語拡張です。
標準SQLにはインデックスに関する規定はありません。
.SH "関連項目"
CREATE INDEX [\fBcreate_index\fR(l)]
