.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_freetuptable" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_freetuptable \- SPI_executeや類似の関数によって生成された行セットを解放します。

.SH SYNOPSIS
.sp
.nf
void SPI_freetuptable(SPITupleTable * \fItuptable\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_freetuptable\fRは、以前に\fBSPI_execute\fRなどのSPIコマンド実行関数によって作成された行セットを解放します。
そのため、この関数は通常SPI_tupletableグローバル変数を引数として呼び出されます。
.PP
この関数はSPIプロシージャが複数のコマンドを実行する必要があり、かつ、初期のコマンドの結果を終わりまで保持したくない場合に有用です。
解放されない行セットは、\fBSPI_finish\fR 時に全て解放されることに注意してください。
.SH "引数"
.TP
\fBSPITupleTable * \fItuptable\fB\fR
解放する行セットへのポインタ。
