.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "EXECUTE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
EXECUTE \- 準備された文の実行

.SH SYNOPSIS
.sp
.nf
EXECUTE \fIplan_name\fR [ (\fIparameter\fR [, ...] ) ]
.sp
.fi
.SH "説明"
.PP
\fBEXECUTE\fRは、既に準備済である文を実行する際に使用します。 
準備された文はセッション中にしか存在できないため、準備された文は、同じセッション中の前の段階で\fBPREPARE\fR文によって作成されたものでなければなりません。
.PP
文を作成した\fBPREPARE\fR文にパラメータが指定されている場合には、これに適合するパラメータの集合が\fBEXECUTE\fRに渡される必要があります。
渡されないと、エラーになります。 
(関数とは異なり)準備された文は、パラメータのデータ型や数によって上書きされることはありません。 
準備された文の名前は、1 つのデータベースセッション内で一意でなければなりません。
.PP
準備された文の作成と使用方法についての詳細はPREPARE [\fBprepare\fR(l)]を参照してください。
.SH "パラメータ"
.TP
\fB\fIplan_name\fB\fR
実行する準備された文の名前です。
.TP
\fB\fIparameter\fB\fR
準備された文に対するパラメータの実際の値です。 
この値は、この準備された文を作成した\fBPREPARE\fR文内でこのパラメータ位置に指定したデータ型と互換性のあるデータ型の値を生み出す式である必要があります。
.SH "出力"
.PP
\fBEXECUTE\fRで返されるコマンドタグは、EXECUTEではなく、準備済み文のコマンドタグとなります。
.SH "例"
.PP
例はPREPARE [\fBprepare\fR(l)]文書の例 [\fBprepare\fR(l)]節にあります。
.SH "互換性"
.PP
標準SQLには\fBEXECUTE\fR文が含まれていますが、これは埋め込みSQLでのみ使用できます。 
また、このバージョンの\fBEXECUTE\fR文では多少異なる構文が使用されます。
.SH "関連項目"
DEALLOCATE [\fBdeallocate\fR(l)], PREPARE [\fBprepare\fR(l)]
