.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_repalloc" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_repalloc \- 上位エクゼキュータコンテキスト内にメモリを再割当します。

.SH SYNOPSIS
.sp
.nf
void * SPI_repalloc(void * \fIpointer\fR, Size \fIsize\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_repalloc\fRは、以前に\fBSPI_palloc\fRを使用して割り当てられたメモリセグメントのサイズを変更します。
.PP
この関数はもはや通常の\fBrepalloc\fRとは異なるものではありません。
単に既存コードの後方互換性のために保持されています。
.SH "引数"
.TP
\fBvoid * \fIpointer\fB\fR
変更する既存の領域へのポインタ。
.TP
\fBSize \fIsize\fB\fR
割り当てる領域のバイト数。
.SH "戻り値"
.PP
指定サイズに新規に割り当てられ、既存領域の内容をコピーした領域へのポインタ。
