.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_exec" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_exec \- 読み書きコマンドを実行します。

.SH SYNOPSIS
.sp
.nf
int SPI_exec(const char * \fIcommand\fR, int \fIcount\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_exec\fRは、常に\fIread_only\fRパラメータをfalseとした\fBSPI_execute\fRと同じです。
.SH "引数"
.TP
\fBconst char * \fIcommand\fB\fR
実行するコマンドを含む文字列。
.TP
\fBint \fIcount\fB\fR
処理される、あるいは、返される行の最大数。
.SH "戻り値"
.PP
\fBSPI_execute\fRを参照してください。
