.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_getrelname" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_getrelname \- 指定されたリレーションの名前を返します。

.SH SYNOPSIS
.sp
.nf
char * SPI_getrelname(Relation \fIrel\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_getrelname\fRは指定リレーションの名前のコピーを返します。
(不要になった段階で、\fBpfree\fRを使用して名前のコピーを解放することができます。)
.SH "引数"
.TP
\fBRelation \fIrel\fB\fR
入力リレーション。
.SH "戻り値"
.PP
指定されたリレーションの名前。
