.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TRIGGER" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER TRIGGER \- トリガ定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER TRIGGER \fIname\fR ON \fItable\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER TRIGGER\fRを使用すると、既存のトリガのプロパティを変更できます。 
RENAME句を使用すると、トリガ定義を変更せずに、指定されたテーブルのトリガ名を変更することができます。
.PP
トリガのプロパティを変更するには、トリガで処理されるテーブルを所有している必要があります。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
変更の対象となる既存のトリガの名前です。
.TP
\fB\fItable\fB\fR
このトリガで処理されるテーブルの名前です。
.TP
\fB\fInewname\fB\fR
既存のトリガの新しい名前です。
.SH "例"
.PP
既存のトリガの名前を変更します。
.sp
.nf
ALTER TRIGGER emp_stamp ON emp RENAME TO emp_track_chgs;
.sp
.fi
.SH "互換性"
.PP
\fBALTER TRIGGER\fRは、標準SQLに対するPostgreSQLの拡張です。
