.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_getvalue" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_getvalue \- 指定された列の文字列値を返します。

.SH SYNOPSIS
.sp
.nf
char * SPI_getvalue(HeapTuple \fIrow\fR, TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_getvalue\fRは、指定された列の値の文字列表現を返します。
.PP
結果は、\fBpalloc\fRを使用して割り当てられたメモリ内に返されます。
(不要になった段階で、\fBpfree\fRを使用してメモリを解放することができます。)
.SH "引数"
.TP
\fBHeapTuple \fIrow\fB\fR
検査対象の入力行。
.TP
\fBTupleDesc \fIrowdesc\fB\fR
入力行の記述。
.TP
\fBint \fIcolnumber\fB\fR
(1から始まる)列番号。
.SH "戻り値"
.PP
列の値。
列がNULLの場合、あるいは、\fIcolnumber\fRが範囲外の場合は\fBNULL\fRです。(SPI_result が \fBSPI_ERROR_NOATTRIBUTE\fR に設定されます。)
利用できる出力関数が存在しない場合は、\fBNULL\fRです。
(SPI_result が\fBSPI_ERROR_NOOUTFUNC\fRに設定されます。)
