.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE TABLESPACE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE TABLESPACE \- 新しいテーブル空間の定義

.SH SYNOPSIS
.sp
.nf
CREATE TABLESPACE \fItablespacename\fR [ OWNER \fIusername\fR ] LOCATION '\fIdirectory\fR'
.sp
.fi
.SH "説明"
.PP
\fBCREATE TABLESPACE\fRはクラスタ全体で使用できるテーブル空間を新規に登録します。
このテーブル空間名はデータベースクラスタ内の既存のテーブル空間の名前と異なるものでなければなりません。
.PP
テーブル空間によって、スーパーユーザはデータベースオブジェクト(テーブルやインデックスなど)を構成するデータファイルを格納するファイルシステム上の場所を別途定義することができます。
.PP
適切な権限を持つユーザは、\fBCREATE DATABASE\fRや\fBCREATE TABLE\fR、\fBCREATE INDEX\fR、\fBADD CONSTRAINT\fRコマンドに\fItablespacename\fRを渡すことで、指定したテーブル空間にこれらのオブジェクトを格納させることができます。
.SH "パラメータ"
.TP
\fB\fItablespacename\fB\fR
作成するテーブル空間の名前です。
システム向けのテーブル空間用に予約されていますので、この名前をpg_から始めることはできません。
.TP
\fB\fIusername\fB\fR
テーブル空間を所有するユーザの名前です。
省略時はデフォルトでコマンドを実行したユーザとなります。
スーパーユーザのみがテーブル空間を作成することができますが、テーブル空間の所有権を非スーパーユーザに割り当てることは可能です。
.TP
\fB\fIdirectory\fB\fR
テーブル空間用に使用するディレクトリです。
このディレクトリは空でなければならず、また、PostgreSQLシステムユーザが所有していなければなりません。
このディレクトリは絶対パス名で指定する必要があります。
.SH "注釈"
.PP
シンボリックリンクをサポートしているシステムのみ、テーブル空間をサポートします。
.SH "例"
.PP
/data/dbsにdbspaceテーブル空間を作成します。
.sp
.nf
CREATE TABLESPACE dbspace LOCATION '/data/dbs';
.sp
.fi
.PP
/data/indexesに、genevieveユーザが所有するindexspaceテーブル空間を作成します。
.sp
.nf
CREATE TABLESPACE indexspace OWNER genevieve LOCATION '/data/indexes';
.sp
.fi
.SH "互換性"
.PP
\fBCREATE TABLESPACE\fRはPostgreSQLの拡張です。
.SH "関連項目"
CREATE DATABASE [\fBcreate_database\fR(l)], CREATE TABLE [\fBcreate_table\fR(l)], CREATE INDEX [\fBcreate_index\fR(l)], DROP TABLESPACE [\fBdrop_tablespace\fR(l)], ALTER TABLESPACE [\fBalter_tablespace\fR(l)]
