.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TABLESPACE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER TABLESPACE \- テーブル空間の定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER TABLESPACE \fIname\fR RENAME TO \fInewname\fR
ALTER TABLESPACE \fIname\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER TABLESPACE\fRはテーブル空間の定義を変更します。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存のテーブル空間の名前です。
.TP
\fB\fInewname\fB\fR
新しいテーブル空間の名前です。
システム用のテーブル空間用に予約されているため、新しい名前にはpg_から始める名前を付けることはできません。
.TP
\fB\fInewowner\fB\fR
新しいテーブル空間の所有者です。
テーブル空間の所有者を変更するにはスーパーユーザでなければなりません。
.SH "例"
.PP
index_spaceテーブル空間をfast_raidという名前に変更します。
.sp
.nf
ALTER TABLESPACE index_space RENAME TO fast_raid;
.sp
.fi
.PP
index_spaceテーブル空間の所有者を変更します。
.sp
.nf
ALTER TABLESPACE index_space OWNER TO mary;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER TABLESPACE\fR文はありません。
.SH "関連項目"
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)], DROP TABLESPACE [\fBdrop_tablespace\fR(l)]
