.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE GROUP" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE GROUP \- 新しいグループの定義

.SH SYNOPSIS
.sp
.nf
CREATE GROUP \fIname\fR [ [ WITH ] \fIoption\fR [ ... ] ]

ここで、\fIoption\fRは以下の通りです。

     SYSID \fIgid\fR
   | USER  \fIusername\fR [, ...]
.sp
.fi
.SH "説明"
.PP
\fBCREATE GROUP\fRはに新しいユーザグループを作成します。
このコマンドを使用するにはデータベースのスーパーユーザでなければなりません。
.PP
ユーザとグループは、データベースクラスタのレベルで定義されるため、クラスタ内の全てのデータベースで有効になることに注意してください。
.PP
グループのメンバ資格を変更する場合はALTER GROUP [\fBalter_group\fR(l)]を、グループを削除する場合はDROP GROUP [\fBdrop_group\fR(l)]を使用してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
グループの名前です。
.TP
\fB\fIgid\fB\fR
SYSID句を使用して、新しいグループのPostgreSQLグループIDを選ぶことができます。
これは通常必要ありませんが、オブジェクトの権限において参照されるグループを再作成しなければならなくなった場合に訳に立つかもしれません。

これが指定されないと、割り当て済みのグループIDの中で最も高い数値に1を足した値(最小は100)がデフォルトとして使われます。
.TP
\fB\fIusername\fB\fR
グループに含めるユーザのリストです。既存のユーザでなければいけません。
.SH "例"
.PP
空のグループを作成します。
.sp
.nf
CREATE GROUP staff;
.sp
.fi
.PP
メンバを持つグループを作成します。
.sp
.nf
CREATE GROUP marketing WITH USER jonathan, david;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBCREATE GROUP\fRはありません。
roleという概念がグループと似ています。
.SH "関連項目"
ALTER GROUP [\fBalter_group\fR(l)], DROP GROUP [\fBdrop_group\fR(l)]
