.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CHECKPOINT" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CHECKPOINT \- 強制的なトランザクションログのチェックポイントの実行

.SH SYNOPSIS
.sp
.nf
CHECKPOINT
.sp
.fi
.SH "説明"
.PP
WAL（ログ先行書き込み）は、頻繁にチェックポイントをトランザクションログに設定します（自動的なチェックポイントの間隔の調整については、実行時構成オプションのcheckpoint_segmentsとcheckpoint_timeoutを参照してください）。
\fBCHECKPOINT\fRコマンドは、コマンドが発行されると、予定されているチェックポイントを待つことなく、即座にチェックポイントを設定します。
.PP
チェックポイントは、ログ内の情報を反映するために全てのデータファイルが更新された時点を示す、連続したトランザクションログにおけるある時点です。
全てのデータファイルはディスクに書き出されます。
WALシステムの詳細については、the documentationを参照してください。
.PP
スーパーユーザだけが\fBCHECKPOINT\fRを実行できます。
このコマンドは、通常動作での使用は目的としていません。
.SH "互換性"
.PP
\fBCHECKPOINT\fRコマンドは、PostgreSQLの言語拡張です。
