.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_execute_plan" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_execute_plan \- SPI_prepareで準備された計画を実行します。

.SH SYNOPSIS
.sp
.nf
int SPI_execute_plan(void * \fIplan\fR, Datum * \fIvalues\fR, const char * \fInulls\fR,
                     bool \fIread_only\fR, int \fIcount\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_execute_plan\fRは、\fBSPI_prepare\fRで準備された計画を実行します。
\fIread_only\fRと\fIcount\fRは、\fBSPI_execute\fRと同様の解釈がなされます。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
(\fBSPI_prepare\fRで返される)実行計画。
.TP
\fBDatum * \fIvalues\fB\fR
実パラメータ値の配列。
計画の引数の数と同じ長さでなければなりません。
.TP
\fBconst char * \fInulls\fB\fR
どのパラメータがNULLであるかを示す配列。
計画の引数の数と同じ長さでなければなりません。
nはNULL値を表します。(\fIvalues\fR内の項目は無視されます。)
空白は非NULLの値を表します。(\fIvalues\fR内の項目は有効です。)

\fInulls\fR が \fBNULL\fR の場合、\fBSPI_execute_plan\fRは全てのパラメータがNULLではないとみなします。
.TP
\fBbool \fIread_only\fB\fR
読み取りのみの実行の場合true。
.TP
\fBint \fIcount\fB\fR
処理される、もしくは、返される行の最大値
.SH "戻り値"
.PP
戻り値は、\fBSPI_execute\fR同様のものに加え、以下のエラー（負）の結果をとることがあります。
.TP
\fBSPI_ERROR_ARGUMENT\fR
\fIplan\fR が \fBNULL\fR あるいは、\fIcount\fR が0未満の場合。
.TP
\fBSPI_ERROR_PARAM\fR
\fIvalues\fR が \fBNULL\fR 、かつ、\fIplan\fR がパラメータ付きで準備された場合。
.PP
.PP
成功時、SPI_processed とSPI_tuptableが \fBSPI_execute\fR 同様に設定されます。
.SH "注意"
.PP
準備された計画で参照されるオブジェクト(テーブル、関数、など)のいずれかがセッション中に削除された場合、その計画用の\fBSPI_execute_plan\fRの結果は予測不能です。
