.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER GROUP" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER GROUP \- ユーザグループの変更

.SH SYNOPSIS
.sp
.nf
ALTER GROUP \fIgroupname\fR ADD USER \fIusername\fR [, ... ]
ALTER GROUP \fIgroupname\fR DROP USER \fIusername\fR [, ... ]

ALTER GROUP \fIgroupname\fR RENAME TO \fInewname\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER GROUP\fRはユーザグループの属性を変更します。
.PP
最初の2構文は、ユーザをグループに追加もしくはグループから削除します。
データベーススーパーユーザのみがこのコマンドを使うことができます。
.PP
3番目の構文はグループの名前を変更します。
データベーススーパーユーザのみがグループ名を変更することができます。
.SH "パラメータ"
.TP
\fB\fIgroupname\fB\fR
変更するグループの名前です。
.TP
\fB\fIusername\fB\fR
グループに追加もしくは削除されるユーザです。
ユーザは存在するものでなければいけません。
\fBALTER GROUP\fRは、ユーザの作成も削除も行いません。
.TP
\fB\fInewname\fB\fR
新しいグループ名です。
.SH "例"
.PP
ユーザをグループに追加します。
.sp
.nf
ALTER GROUP staff ADD USER karl, john;
.sp
.fi
ユーザをグループから削除します。
.sp
.nf
ALTER GROUP workers DROP USER beth;
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER GROUP\fR文はありません。
ロールが概念的に似ています。
.SH "関連項目"
CREATE GROUP [\fBcreate_group\fR(l)], DROP GROUP [\fBdrop_group\fR(l)]
