.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SELECT" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
SELECT \- テーブルもしくはビューからの行の検索

.SH SYNOPSIS
.sp
.nf
SELECT [ ALL | DISTINCT [ ON ( \fIexpression\fR [, ...] ) ] ]
    * | \fIexpression\fR [ AS \fIoutput_name\fR ] [, ...]
    [ FROM \fIfrom_item\fR [, ...] ]
    [ WHERE \fIcondition\fR ]
    [ GROUP BY \fIexpression\fR [, ...] ]
    [ HAVING \fIcondition\fR [, ...] ]
    [ { UNION | INTERSECT | EXCEPT } [ ALL ] \fIselect\fR ]
    [ ORDER BY \fIexpression\fR [ ASC | DESC | USING \fIoperator\fR ] [, ...] ]
    [ LIMIT { \fIcount\fR | ALL } ]
    [ OFFSET \fIstart\fR ]
    [ FOR UPDATE [ OF \fItable_name\fR [, ...] ] ]

ここで\fIfrom_item\fRは以下のいずれかです。

    [ ONLY ] \fItable_name\fR [ * ] [ [ AS ] \fIalias\fR [ ( \fIcolumn_alias\fR [, ...] ) ] ]
    ( \fIselect\fR ) [ AS ] \fIalias\fR [ ( \fIcolumn_alias\fR [, ...] ) ]
    \fIfunction_name\fR ( [ \fIargument\fR [, ...] ] ) [ AS ] \fIalias\fR [ ( \fIcolumn_alias\fR [, ...] | \fIcolumn_definition\fR [, ...] ) ]
    \fIfunction_name\fR ( [ \fIargument\fR [, ...] ] ) AS ( \fIcolumn_definition\fR [, ...] )
    \fIfrom_item\fR [ NATURAL ] \fIjoin_type\fR \fIfrom_item\fR [ ON \fIjoin_condition\fR | USING ( \fIjoin_column\fR [, ...] ) ]
.sp
.fi
.SH "説明"
.PP
\fBSELECT\fRは1つ以上のテーブルから行を返します。
\fBSELECT\fRの一般的な処理は以下の通りです。
.IP 1. 
FROMリストにある全要素が計算されます。
(FROMリストの各要素は実テーブルか仮想テーブルです。)
FROMリストに複数の要素が指定された場合、それらはクロス結合されます。
(後述のFROM 句 [\fBselect\fR(l)]を参照してください。)
.IP 2. 
WHERE句が指定された場合、条件を満たさない行は全て出力から取り除かれます。
(後述のWHERE 句 [\fBselect\fR(l)]を参照してください。)
.IP 3. 
GROUP BY句が指定された場合、出力は、1つ以上の値に一致する行のグループに分割されます。
HAVING句が指定された場合、指定した条件を満たさないグループは取り除かれます。
(後述のGROUP BY 句 [\fBselect\fR(l)]とHAVING 句 [\fBselect\fR(l)]を参照してください。)
.IP 4. 
実際の出力行は、選択された各行に対して、\fBSELECT\fR出力式を使用して計算されたものです。
(後述のSELECT リスト [\fBselect\fR(l)]を参照してください。)
.IP 5. 
UNION、INTERSECT、および、EXCEPT演算子を使用すると、複数の\fBSELECT\fR文の出力を1つの結果集合にまとめることができます。
UNION演算子は、両方あるいは片方の結果集合に存在する行を全て返します。
INTERSECT演算子は両方の結果集合に存在する行を全て返します。
EXCEPT演算子は最初の結果集合にあり、2番目の結果集合に無い行を返します。
ALLが指定されない限り、これら3つとも、重複する行は取り除かれます。
(後述のUNION 句 [\fBselect\fR(l)]、INTERSECT 句 [\fBselect\fR(l)]、および、EXCEPT 句 [\fBselect\fR(l)]を参照してください。)
.IP 6. 
ORDER BY句が指定された場合、返される行は指定した順番でソートされます。
ORDER BYが指定されない場合は、システムが計算過程で最初に見付けたものという何らかの順番で行が返されます。
(後述のORDER BY 句 [\fBselect\fR(l)]を参照してください。)
.IP 7. 
DISTINCTは結果から重複行を取り除きます。
DISTINCT ONは、指定された式全てに一致する行を取り除きます。
(デフォルトの)ALLは重複した行も含め、全ての候補行を返します。
(後述のDISTINCT 句 [\fBselect\fR(l)]を参照してください。)
.IP 8. 
LIMITあるいはOFFSET句が指定された場合、\fBSELECT\fR文は結果行の一部分のみを返します。
(後述のLIMIT 句 [\fBselect\fR(l)]を参照してください。)
.IP 9. 
FOR UPDATE句により、\fBSELECT\fR文は、引続き実行される更新用に選択行をロックします。
(後述のFOR UPDATE 句 [\fBselect\fR(l)]を参照してください。)
.PP
.PP
テーブルから値を読み取るためにはSELECT権限が必要です。
FOR UPDATEを使用するためには、同様にUPDATE権限が必要です。
.SH "パラメータ"
.SS "FROM 句"
.PP
FROM句は\fBSELECT\fRの対象となるソーステーブルを1つ以上指定します。
複数のソースが指定された場合、結果は全てのソースの直積(クロス結合)となります。
しかし、通常は直積の小さな一部分を返すように制限するために制約条件が付け加えられます。
.PP
FROM句には以下の要素を指定できます。
.TP
\fB\fItable_name\fB\fR
既存のテーブルもしくはビューの名前です(スキーマ修飾名でも可)。
ONLYが指定された場合、そのテーブルのみがスキャンされます。
もし ONLYが指定されない場合、テーブルと(もしあれば)それを継承する全てのテーブルがスキャンされます。
子テーブルがスキャンされることを表すために、テーブル名に*を付けることができますが、現在のバージョンでは、子テーブルのスキャンはデフォルトで行われます。
(7.1より前のリリースでは、ONLYがデフォルトでした。) 
デフォルトの振舞いを変更するには、sql_inheritance設定オプションを変更します。
.TP
\fB\fIalias\fB\fR
別名を含むFROMアイテムの代替名です。
別名は簡潔さのため、もしくは自己結合(同じテーブルが複数回スキャンされる場合です)の曖昧さをなくすために使われます。
別名が指定されている場合は、その別名によって実際のテーブル名または関数名が完全に隠されます。
例えば、FROM foo AS fと指定されている場合、以降の\fBSELECT\fR文ではこのFROMアイテムをfooではなくfとして参照する必要があります。
テーブルの別名があれば、そのテーブルの複数の列の名前を置き換える列の別名リストを記述することができます。
.TP
\fB\fIselect\fB\fR
副\fBSELECT\fRはFROM句で使うことができます。
これは、その出力がこの\fBSELECT\fRコマンド実行時に一時テーブルとして作成されたかのように動作します。
副\fBSELECT\fRは括弧で囲まれなければならず、\fB必ず\fR別名が提供されなければなりません。
.TP
\fB\fIfunction_name\fB\fR
FROM句に関数呼び出しを使用することができます。
(これは特に関数が結果セットを返す場合に有用なものですが、任意の関数を使用することができます。)
これは、その出力がこの\fBSELECT\fRコマンド実行時に一時テーブルとして作成されたかのように動作します。 
また、別名を使用することもできます。 
別名があれば、その関数の複合戻り型の複数の属性の代替名を提供する別名リストを記述することができます。
関数が\fBrecord\fRデータ型を返すものと定義されている場合は、別名すなわちASキーワードとそれに続く( \fIcolumn_name\fR \fIdata_type\fR [, ... ])という形式の列定義リストが必要です。
列定義リストは、関数によって返される実際の列の数およびデータ型に一致していなければなりません。
.TP
\fB\fIjoin_type\fB\fR
以下のいずれかです。
.RS
.TP 0.2i
\(bu
[ INNER ] JOIN
.TP 0.2i
\(bu
LEFT [ OUTER ] JOIN
.TP 0.2i
\(bu
RIGHT [ OUTER ] JOIN
.TP 0.2i
\(bu
FULL [ OUTER ] JOIN
.TP 0.2i
\(bu
CROSS JOIN
.RE
.PP
INNER、および、OUTER結合型では、結合条件、すなわち、NATURAL, ON \fIjoin_condition\fR、もしくは、USING (\fIjoin_column\fR [, ...])のいずれかを1つのみ指定する必要があります。
意味は後で説明します。
CROSS JOINでは、これらの句を記述しなくても構いません。

JOIN句は、2つのFROMアイテムを結び付けます。
入れ子の順番を決めるために、必要ならば括弧を使用してください。
括弧が無いと、JOINは左から右へと入れ子にされます。
どのような場合でもJOINは、カンマで分けられたFROM項目よりも強く結び付きます。

CROSS JOINとINNER JOINは、FROMの最上位で2つの項目を付けた結果と同一の、1つの直積を生成します。
しかし、(もしあれば)結合条件で制限をかけることができます。
CROSS JOINはINNER JOIN ON (true)と等価であり、条件によって削除される行はありません。
これらの結合型は記述上の便宜のためだけのものです。
従って、通常のFROMとWHEREを行わないと何も行いません。

LEFT OUTER JOINは条件に合う直積の全ての行(つまり、その結合条件を満たす全ての組み合わされた行)に加え、右側の行を持たないが結合条件を満たす左側のテーブルの各々の行のコピーを返します。 
この左側の行は右側の行にNULL値を挿入することで結合されたテーブルの全幅に拡張されます。 
どの行がマッチしているかを決める間、JOIN句自身の条件のみが考慮されることに注意してください。
他の外部結合条件は後で適用されます。

逆に、RIGHT OUTER JOINは全ての結合された行と、それぞれの当てはまるものがなかった右側の行(左側はNULLで拡張されています)に一行ずつを返します。
左と右の入力を入れ換えることでLEFT OUTER JOINに変換することもできるため、これはただの記述上の便宜でしかありません。

FULL OUTER JOINは、全ての結合された行、一致しなかった左側の行(を右側をNULLで拡張させた行)を1行ずつ、更に、一致しなかった右側の行(を左側をNULLで拡張させた行)を1行ずつ返します。
.TP
\fBON \fIjoin_condition\fB\fR
\fIjoin_condition\fRは、結合においてどの行が一致したとみなすかどうかを指定する(WHERE句同様)\fBboolean\fR型の値を返す式です。
.TP
\fBUSING (\fIjoin_column\fB [, ...])\fR
USING ( a, b, ... )句はON left_table.a = right_table.a AND left_table.b = right_table.b ...の省略形です。
USINGは等価となる列の組合せの両方ではなく片方のみが結合の出力に含まれることを意味します。
.TP
\fBNATURAL\fR
NATURALは2つのテーブル内の同じ名前を持つ全てを指定したUSINGリストの省略形です。
.PP
.SS "WHERE 句"
.PP
省略可能なWHERE句は通常以下の形式となります。
.sp
.nf
WHERE \fIcondition\fR
.sp
.fi
ここで、\fIcondition\fRは、評価の結果\fBboolean\fR型を返す任意の式です。
この条件を満たさない行は全て出力から取り除かれます。
全ての変数参照に実際の行の値を代入した時に式が真を返す場合に、行は条件を満たします。
.SS "GROUP BY 句"
.PP
省略可能なGROUP BY句は通常以下の形式となります。
.sp
.nf
GROUP BY \fIexpression\fR [, ...]
.sp
.fi
.PP
GROUP BYは、グループ化式で同じ値を共有する全ての行を1つの行に凝縮します。
\fIexpression\fRは、入力列名か、出力列(\fBSELECT\fRリスト項目)の名前もしくは序数、もしくは、入力列の値から計算される任意の式を取ることができます。
曖昧な場合、GROUP BYの名前は出力列名ではなく入力列名として解釈されます。
.PP
集約関数がもし使用されていると、各グループを生成する全ての行に対して計算され、グループ毎に分けた値が生成されます。
(一方GROUP BYが無い場合は、集約関数は全ての選択された行に対して計算され、1つの値を生成します。)
GROUP BYがあると、集約関数内部以外でグループ化されていない列を参照する\fBSELECT\fRリストは無効になります。
グループ化されていない列について返される値は複数の値になってしまうからです。
.SS "HAVING 句"
.PP
省略可能なHAVINGは通常以下の形になります。
.sp
.nf
HAVING \fIcondition\fR
.sp
.fi
ここで\fIcondition\fRはWHERE句で指定するものと同じです。
.PP
HAVINGはこの条件を満たさないグループ化された行を取り除きます。
HAVINGはWHEREとは違います。
WHEREでは、GROUP BYの適用前に、個別の行に対してフィルタを行い、HAVINGはGROUP BYで生成されたグループ化された行に対してフィルタを行います。
\fIcondition\fR内の列参照は、集約関数内で表れる参照を除き、曖昧さが無いグループ化された列を参照しなければなりません。
.SS "SELECT リスト"
.PP
\fBSELECT\fRリスト(SELECTとFROMの間にあるキーワード)は、\fBSELECT\fR文の出力行を形成する式を指定したものです。
この式では、FROM句内で計算された列を参照することができます(そして、通常は参照します)。
AS \fIoutput_name\fRを使用して、出力列とは別の名前を指定できます。
この名前は主に表示用の列ラベルとして使われます。
また、ORDER BYとGROUP BY句内で列の値を参照するためにも使用されます。
しかし、WHEREやHAVING句では使用されず、ここには式を書かなければなりません。
.PP
式の代わりに、選択された行の全ての列を表す省略形として、出力リストに*と書くことができます。
また、そのテーブルのみに由来する列を表す省略形として、\fItable_name\fR.*と書くこともできます。
.SS "UNION 句"
.PP
UNIONは通常以下の形式となります。
.sp
.nf
\fIselect_statement\fR UNION [ ALL ] \fIselect_statement\fR
.sp
.fi
\fIselect_statement\fRは、ORDER BY、LIMIT、FOR UPDATE句を持たない、任意の\fBSELECT\fR文です。
(もし括弧で括られていたら、ORDER BYとLIMITは副式に付与できます。
括弧が無いと、これらの句は右側の入力式にではなく、UNIONの結果に対して適用されてしまいます。)
.PP
UNION演算子は、呼び出された\fBSELECT\fR文で返される行の和集合を計算します。
少なくともどちらか片方に表れれば、その行は2つの結果セットの和集合内にあります。
直接UNIONの演算項目となる\fBSELECT\fR文は、同じ列数を返さなければならず、また、対応する列のデータ型には互換性が必要です。
.PP
ALLオプションが指定されていないと、UNIONの結果には重複行は含まれません。
ALLは重複除去を行いません。
(従って、通常UNION ALLはUNIONよりかなり高速です。
できるだけALLを使用してください。)
.PP
一つの\fBSELECT\fR文で複数のUNION演算子がある場合、括弧で示されない限り、その評価は左から右に行われます。
.PP
現時点では、FOR UPDATEをUNIONの結果に対しても、UNIONの何らかの入力に対しても指定することができません。
.SS "INTERSECT 句"
.PP
INTERSECTは通常以下の形式となります。
.sp
.nf
\fIselect_statement\fR INTERSECT [ ALL ] \fIselect_statement\fR
.sp
.fi
\fIselect_statement\fRは、ORDER BY、LIMIT、FOR UPDATEを持たない、任意の\fBSELECT\fR文です。
.PP
INTERSECTは、呼び出される\fBSELECT\fR文が返す行の積集合を計算します。
両方の結果セットに現れる場合、その行は2つの結果セットの積集合内に存在します。
.PP
ALLオプションが指定されていないと、INTERSECTの結果には重複行は含まれません。
ALLがある場合、左側テーブルに\fIm\fR個の重複、右側テーブルに\fIn\fR個の重複がある行は、結果セットにmin(\fIm\fR,\fIn\fR)個出現します。
.PP
一つの\fBSELECT\fR文で複数のINTERSECT演算子がある場合、括弧で示されない限り、その評価は左から右に行われます。
INTERSECTはUNIONよりも強い結び付きです。
つまり、A UNION B INTERSECT C はA UNION (B INTERSECT C)と解釈されます。
.PP
現時点では、FOR UPDATEをINTERSECTの結果に対しても、INTERSECTの何らかの入力に対しても指定することができません。
.SS "EXCEPT 句"
.PP
EXCEPTは通常以下の形式となります。
.sp
.nf
\fIselect_statement\fR EXCEPT [ ALL ] \fIselect_statement\fR
.sp
.fi
\fIselect_statement\fRは、ORDER BY、LIMIT、FOR UPDATE句を持たない、任意の\fBSELECT\fR文です。 
.PP
EXCEPTは、左側の\fBSELECT\fR文の結果に存在し、右側の結果には存在しない行の集合を計算します。
.PP
ALLオプションが指定されていないと、EXCEPTの結果には重複行は含まれません。
ALLがある場合、左側テーブルに\fIm\fR個の重複、右側テーブルに\fIn\fR個の重複がある行は、結果セットにmax(\fIm\fR-\fIn\fR,0)個出現します。
.PP
一つの\fBSELECT\fR文で複数のEXCEPT演算子がある場合、括弧で示されない限り、その評価は左から右に行われます。
EXCEPTの結び付きのレベルはUNIONと同じです。
.PP
現時点では、FOR UPDATEをEXCEPTの結果に対しても、EXCEPTの何らかの入力に対しても指定することができません。
.SS "ORDER BY 句"
.PP
省略可能なORDER BY句は通常以下の形式となります。
.sp
.nf
ORDER BY \fIexpression\fR [ ASC | DESC | USING \fIoperator\fR ] [, ...]
.sp
.fi
\fIexpression\fRには、出力列(\fBSELECT\fRリスト項目)の名前もしくは序数、あるいは、入力列値から形成される任意の式をとることができます。
.PP
ORDER BY句により、結果の行を指定した式に従ってソートすることができます。
もっとも左にある式で2つの行が等しくなった場合は、次の式に従い、それも等しければ更に次の式に進みます。
指定した式の全てで等しくなった場合は、実装に依存した順番で返されます。
.PP
序数とは、結果列の(左から右への)順序の位置です。
この機能により、一意な名前を持たない列に対して順序を定義することができます。
AS句を使用すれば結果列に名前を割り当てることができますので、これは決して必要なものではありません。
.PP
また、ORDER BY句には、\fBSELECT\fR結果リストに出現しない列を含む、任意の式を使用できます。
従って、以下の文は有効なものです。
.sp
.nf
SELECT name FROM distributors ORDER BY code;
.sp
.fi
この機能の制限は、UNION、INTERSECT、EXCEPTの結果にORDER BYを適用する場合は、式を使用できず、出力列の名前か序数のみを指定できるという点です。
.PP
ORDER BY式が、結果列名と入力列名の両方に一致する単なる名前であった場合、ORDER BYは結果列名としてそれを扱います。
これは、同じ状況におけるGROUP BYの選択とは反対です。
標準SQLとの互換性のためこの不整合が発生しています。
.PP
省略可能なキーワードASC(昇順)、DESC(降順)をORDER BY中の任意の式の後に付け加えることができます。
指定がなければ、デフォルトでASCが付いているものとして扱われます。
別方法に、順序指定演算子名をUSING 句に指定することができます。
通常、ASCはUSING <と、DESCはUSING >と同じです。
(しかし、ユーザ定義のデータ型の作者は、デフォルトのソート順が何かを正しく定義することができ、演算子に異なる名前を対応付けすることもできます。)
.PP
NULL値は他の値よりも高いものとしてソートされます。
言い替えると、昇順のソート順ではNULL値は最後に、降順のソート順ではNULL値は最初にソートされます。
.PP
文字型のデータでは、データベースクラスタの初期化時に決定されるロケール指定の照合順に従ってソートされます。
.SS "DISTINCT 句"
.PP
DISTINCTが指定されると、重複する行は全て結果セットから削除されます。
(各重複行の中で1行のみが保持されます。)
ALLはこの反対のことを指定し、全ての行が保持されます。
これがデフォルトです。
.PP
DISTINCT ON ( \fIexpression\fR [, ...] )は各行集合の中で与えられた式が等しいと評価した、最初の行のみを保持します。
DISTINCT ON式は、(上述の)ORDER BYと同じ規則で扱われます。
各集合の``最初の行''は、ORDER BYを使用して目的の行が最初に現れることを保証しない限り予測することはできません。
例えば、
.sp
.nf
SELECT DISTINCT ON (location) location, time, report
    FROM weather_reports
    ORDER BY location, time DESC;
.sp
.fi
は、各地点の最新の気象情報を取り出します。
しかし、ORDER BYを使用して各地点の時間値を降順に強制しなかったとしたら、各地点の予測できない時間の予報を得ることになります。
.PP
DISTINCT ON式はORDER BY式の最も左側に一致しなければなりません。
ORDER BY句は通常、各DISTINCT ONグループの中で希望する行の優先順位を決定する、追加的な式を含みます。
.SS "LIMIT 句"
.PP
LIMIT句は2つの独立した副句から構成されます。
.sp
.nf
LIMIT { \fIcount\fR | ALL }
OFFSET \fIstart\fR
.sp
.fi
\fIcount\fRは返される行の最大数を指定し、一方、\fIstart\fRは行を返し始める前に飛ばす行数を指定します。
両方とも指定された場合、\fIstart\fR行が飛ばされ、そこから数えて\fIcount\fR行が返されます。
.PP
LIMITを使う時は、結果の行を一意な順番に強制するORDER BY句を使うのが良い考えです。
そうしないと、問い合わせの行の予測不可能なサブセットを得ることになります。 
10から20行目までを出そうとしているかもしれませんが、どの順番の10から20行目までなのでしょうか?
ORDER BYを指定しない限りどの順番なのか分からないのです。
.PP
問い合わせプランナは問い合わせ計画を作成する時にLIMITを考慮しますので、LIMITとOFFSETに何を使用するかによって(異なる行の順番を生む)異なった計画を得ることになるでしょう。
従って、問い合わせの、異なるサブセットを選択するために異なるLIMIT/OFFSETの値を使うと、ORDER BYで予測可能な結果の順序を強制しない限り、\fB矛盾した結果を返します\fR。
これはバグではありません。 
これは、SQLがORDER BYで順番を制御しない限り、問い合わせの結果を特定の順番で返すことを約束しないという事実の本質的な結果なのです。
.SS "FOR UPDATE 句"
.PP
FOR UPDATEは以下の形式となります。
.sp
.nf
FOR UPDATE [ OF \fItable_name\fR [, ...] ]
.sp
.fi
.PP
FOR UPDATEを使用すると、問い合わせによって検索された行が更新用にロックされます。
これにより、現行のトランザクションが終了するまでは、これらの行が他のトランザクションによって変更されたり削除されたりすることがなくなります。
つまり、現行のトランザクションが終了するまでは、他のトランザクションがこれらの行に対して\fBUPDATE\fR、\fBDELETE\fR、または、\fBSELECT FOR UPDATE\fRを試行しても拒否されるのです。
また、他のトランザクションからの\fBUPDATE\fR、\fBDELETE\fR、または、\fBSELECT FOR UPDATE\fRによって選択されている行がロックされている場合に\fBSELECT FOR UPDATE\fRを実行しようとすると、\fBSELECT FOR UPDATE\fRはそのトランザクションが終了するのを待ち、その後更新された行をロックして返します (行が削除された場合は返しません)。
詳細はthe documentationを参照してください。
.PP
FOR UPDATE内に特定のテーブルが指定されている場合は、そのテーブルの行のみがロックされ、\fBSELECT\fR内の他のテーブルは通常通りに読み込まれるだけです。
.PP
FOR UPDATEは、返される行が対応する個々のテーブル行を明確に識別できない場合には使用することができません。
例えば、集約には使用できません。
.PP
FOR UPDATEは、バージョン 7.3より前のPostgreSQLとの互換性のためにLIMITの前に書くことができます。 
しかし、その場合でも実際にはLIMITの後に実行されるので、LIMITの後に書くことをお勧めします。
.SH "例"
.PP
filmsテーブルをdistributorsテーブルと結合します。
.sp
.nf
SELECT f.title, f.did, d.name, f.date_prod, f.kind
    FROM distributors d, films f
    WHERE f.did = d.did

       title       | did |     name     | date_prod  |   kind
-------------------+-----+--------------+------------+----------
 The Third Man     | 101 | British Lion | 1949-12-23 | Drama
 The African Queen | 101 | British Lion | 1951-08-11 | Romantic
 ...
.sp
.fi
.PP
全ての映画のlen列を合計しkind列によって結果をグループ化します。
.sp
.nf
SELECT kind, sum(len) AS total FROM films GROUP BY kind;

   kind   | total
----------+-------
 Action   | 07:34
 Comedy   | 02:58
 Drama    | 14:28
 Musical  | 06:42
 Romantic | 04:38
.sp
.fi
.PP
全ての映画のlen列を合計しkind列によって結果をグループ化し、合計が5時間より少ないグループの合計を表示します。
.sp
.nf
SELECT kind, sum(len) AS total
    FROM films
    GROUP BY kind
    HAVING sum(len) < interval '5 hours';

   kind   | total
----------+-------
 Comedy   | 02:58
 Romantic | 04:38
.sp
.fi
.PP
以下の二つの例は個別の結果を二番目の列(name)の内容に基づいてソートする、同じ方法です。
.sp
.nf
SELECT * FROM distributors ORDER BY name;
SELECT * FROM distributors ORDER BY 2;

 did |       name
-----+------------------
 109 | 20th Century Fox
 110 | Bavaria Atelier
 101 | British Lion
 107 | Columbia
 102 | Jean Luc Godard
 113 | Luso films
 104 | Mosfilm
 103 | Paramount
 106 | Toho
 105 | United Artists
 111 | Walt Disney
 112 | Warner Bros.
 108 | Westward
.sp
.fi
.PP
次の例は、結果をそれぞれのテーブルでWで始まるものだけに制限して、どのようにdistributorsテーブルとactorsテーブルの結合を獲得するかを表しています。
重複しない行のみが必要なので、ALLキーワードは省略されています。
.sp
.nf
distributors:               actors:
 did |     name              id |     name
-----+--------------        ----+----------------
 108 | Westward               1 | Woody Allen
 111 | Walt Disney            2 | Warren Beatty
 112 | Warner Bros.           3 | Walter Matthau
 ...                         ...

SELECT distributors.name
    FROM distributors
    WHERE distributors.name LIKE 'W%'
UNION
SELECT actors.name
    FROM actors
    WHERE actors.name LIKE 'W%';

      name
----------------
 Walt Disney
 Walter Matthau
 Warner Bros.
 Warren Beatty
 Westward
 Woody Allen
.sp
.fi
.PP
この例は、FROM句内での関数の使用方法を、列定義リストがある場合と無い場合の両方に関して示しています。
.sp
.nf
CREATE FUNCTION distributors(int) RETURNS SETOF distributors AS $$
    SELECT * FROM distributors WHERE did = $1;
$$ LANGUAGE SQL;

SELECT * FROM distributors(111);
 did |    name
-----+-------------
 111 | Walt Disney

CREATE FUNCTION distributors_2(int) RETURNS SETOF record AS $$
    SELECT * FROM distributors WHERE did = $1;
$$ LANGUAGE SQL;

SELECT * FROM distributors_2(111) AS (f1 int, f2 text);
 f1  |     f2
-----+-------------
 111 | Walt Disney
.sp
.fi
.SH "互換性"
.PP
当然ながら、\fBSELECT\fR文は標準SQLと互換性があります。
しかし、拡張機能や実現されていない機能もいくつかあります。
.SS "FROM 句の省略"
.PP
PostgreSQLでは、FROM句を省略することができます。
以下のように素直に単純な式の結果を計算させることができます。
.sp
.nf
SELECT 2+2;

 ?column?
----------
        4
.sp
.fi
他のSQLデータベースでは、こういった\fBSELECT\fRを行うためにはダミーの1行テーブルを使わなければなりません。
.PP
明確さはありませんが、普通の\fBSELECT\fRからテーブルを省く、以下のような方法があります。
.sp
.nf
SELECT distributors.* WHERE distributors.name = 'Westward';

 did |   name
-----+----------
 108 | Westward
.sp
.fi
これは、\fBSELECT\fRで参照されるけれども FROMでは記述されないテーブルが、暗黙のFROMアイテムに追加されるので、動作します。
.PP
これは便利な省略形ですが、間違って使いやすいです。
例えば、次のコマンド
.sp
.nf
SELECT distributors.* FROM distributors d;
.sp
.fi
はおそらく間違いです。
ほとんどのユーザは、
.sp
.nf
SELECT d.* FROM distributors d;
.sp
.fi
を意図し、実際に得られる制約の無い結合
.sp
.nf
SELECT distributors.* FROM distributors d, distributors distributors;
.sp
.fi
を意図しないでしょう。
この種の間違いを検出できるように、PostgreSQLは、明示的なFROM句があっても、暗黙的なFROM機能が\fBSELECT\fR文で使用されている場合に警告を発します。
また、add_missing_fromパラメータを偽に設定することで、暗黙的なFROM機能を無効にすることができます。
.SS "AS キーワード"
.PP
標準SQLでは、省略可能なASキーワードは単なるノイズで、その意味に影響すること無く省略することができます。
PostgreSQLのパーサは出力列の名前を変更する際にこのキーワードを必要とします。
なぜなら、型の拡張機能を考えると、このキーワードがないと構文解析の不明瞭さにつながるからです。
しかし、FROMアイテムではASは省略可能です。
.SS "GROUP BYとORDER BYにおける利用可能な名前空間"
.PP
SQL-92では、ORDER BY句は、結果の列名か序数のみを使用することができ、GROUP BY句は、入力列名からなる式のみを使用できます。
PostgreSQLは、これらの句でそれぞれ他の選択が同じようにできるように拡張しています。
(しかし不明瞭さがある場合は標準の解釈が使用されます。)
また、PostgreSQLではどちらの句にも任意の式を指定できます。
式で使われる名前は常に結果列の名前ではなく入力列の名前としてみなされることに注意してください。
.PP
SQL:1999では、SQL-92との上位互換性が全く無い、多少異なった定義を使用します。
しかし、ほとんどの場合、PostgreSQLはSQL:1999と同じ方法でORDER BYやGROUP BYを解釈します。
.SS "非標準句"
.PP
DISTINCT ON、LIMIT、OFFSET句は標準SQLでは定義されていません。
