.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER INDEX" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER INDEX \- インデックス定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER INDEX \fIname\fR 
    \fIaction\fR [, ... ]
ALTER INDEX \fIname\fR
    RENAME TO \fInew_name\fR

ここで\fIaction\fRは以下のいずれかです。

    OWNER TO \fInew_owner\fR
    SET TABLESPACE \fIindexspace_name\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER INDEX\fRは既存のインデックスの定義を変更します。
以下のような複数の副形式が存在します。
.TP
\fBOWNER\fR
この形式では、インデックスの所有者を指定ユーザに変更します。
これはスーパーユーザのみ実行することができます。
.TP
\fBSET TABLESPACE\fR
この形式では、インデックスのテーブル空間を指定したテーブル空間に変更し、インデックスに関連する（複数の）データファイルの移動を行います。
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)]も参照してください。
.TP
\fBRENAME\fR
このRENAME形式では、インデックスの名前を変更します。
格納されたデータには影響ありません。
.PP
.PP
RENAME以外の全ての動作は複数の変更の列挙に組み合わせることができ、その場合、それらの動作並行に処理されます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
変更対象の既存のインデックスの名前です。（スキーマ修飾も可。）
.TP
\fB\fInew_name\fB\fR
インデックスの新しい名前です。
.TP
\fB\fInew_owner\fB\fR
インデックスの新しい所有者のユーザ名です。
.TP
\fB\fItablespace_name\fB\fR
インデックスの移動先のテーブル空間の名前です。
.SH "注釈"
.PP
これらの操作はALTER TABLE [\fBalter_table\fR(l)]を使用しても行うことができます。
実のところ、\fBALTER INDEX\fRは、\fBALTER TABLE\fRのインデックス用の形式のただの別名です。
.PP
システムカタログ用のインデックスに対する変更は全く許されていません。
.SH "例"
.PP
既存のインデックスの名前を変更します。
.sp
.nf
ALTER INDEX distributors RENAME TO suppliers;
.sp
.fi
.PP
インデックスを別のテーブル空間に移動します。
.sp
.nf
ALTER INDEX distributors SET TABLESPACE fasttablespace;
.sp
.fi
.SH "互換性"
.PP
\fBALTER INDEX\fRはPostgreSQLの拡張です。
