.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE TRIGGER" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE TRIGGER \- 新しいトリガの定義

.SH SYNOPSIS
.sp
.nf
CREATE TRIGGER \fIname\fR { BEFORE | AFTER } { \fIevent\fR [ OR ... ] }
    ON \fItable\fR [ FOR [ EACH ] { ROW | STATEMENT } ]
    EXECUTE PROCEDURE \fIfuncname\fR ( \fIarguments\fR )
.sp
.fi
.SH "説明"
.PP
\fBCREATE TRIGGER\fRは新しいトリガを作成します。
そのトリガは指定したテーブルと関連付けられ、特定のイベントが発生した時に指定した関数\fIfuncname\fRを実行します。
.PP
トリガは、行への操作が開始される前(制約条件のチェックと\fBINSERT\fR、\fBUPDATE\fRまたは\fBDELETE\fRが行われる前)、あるいは、操作が完了した後(制約条件がチェックされ、\fBINSERT\fR、\fBUPDATE\fRまたは\fBDELETE\fRが完了した後)のいずれでも起動を指定することができます。
イベントの前にトリガが起動すると、そのトリガは対象行に対する操作を省略することも、(\fBINSERT\fRと\fBUPDATE\fRの操作時のみ)挿入された行を変更することもできます。
イベントの後にトリガが起動すると、最終の挿入、更新あるいは削除を含んだ全ての変更がトリガに``可視''となります。
.PP
FOR EACH ROW付きのトリガは、その操作によって変更される行毎に1回呼び出されます。
例えば、10行に影響を与える\fBDELETE\fR操作は、対象リレーション上のON DELETEトリガを、行が削除される度に1回ずつ、独立して10回呼び出すことになります。
反対に、FOR EACH STATEMENT付きのトリガは、その操作によって何行変更されたかに関わらず、任意の操作毎に1回のみ実行されます。
(特に、0行を変更する操作でも、適用すべきFOR EACH STATEMENTトリガを実行します。)
.PP
同じ種類の複数のトリガが同一イベントに定義された場合、名前のアルファベット順で実行されます。
.PP
\fBSELECT\fRは行を全く変更しませんので、\fBSELECT\fRトリガを作成することはできません。
この場合は、ルールやビューの方がより適しています。
.PP
トリガに関するより詳細については、the documentationを参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
新しいトリガに付与する名前です。
この名前は、同じテーブルの他のトリガとは異なる名前にする必要があります。
.TP
\fBBEFORE\fR
.TP
\fBAFTER\fR
関数の呼び出しをイベントの前に行うか後に行うかを決定します。
.TP
\fB\fIevent\fB\fR
\fBINSERT\fR、\fBUPDATE\fR、\fBDELETE\fRのいずれかです。
これは、トリガを起動するイベントを指定するものです。
ORを使用して、複数のイベントを指定することができます。
.TP
\fB\fItable\fB\fR
トリガを作成するテーブルの名前です (スキーマ修飾名でも可)。
.TP
\fBFOR EACH ROW\fR
.TP
\fBFOR EACH STATEMENT\fR
これは、トリガプロシージャの起動を、トリガイベントによって影響を受ける行毎に1回行うか、SQL文毎に1回のみ行うかを指定します。
どちらも指定されない場合は、FOR EACH STATEMENTがデフォルトです。
.TP
\fB\fIfuncname\fB\fR
引数を取らず、trigger型を返す、ユーザが提供する関数であり、トリガが起動した時に実行されます。
.TP
\fB\fIarguments\fB\fR
トリガ実行時に関数に渡される引数をカンマで区切ったリストです(省略可能)。
引数は、リテラル文字列定数です。
単純な名前および数値定数もここに記述できますが、全て文字列に変換されます。
関数内でどのようにこのトリガ引数にアクセスするかについては、トリガ関数を実装した言語の説明を参照してください。
これは、通常の関数引数とは異なる場合があります。
.SH "注釈"
.PP
テーブルにトリガを作成するには、ユーザはそのテーブルに対しTRIGGER権限を持つ必要があります。
.PP
PostgreSQL 7.3より前のバージョンでは、トリガ関数を\fBtrigger\fR型ではなくプレースホルダ用の\fBopaque\fR型を返すように宣言する必要がありました。
古いダンプファイルのロードをサポートするため、\fBCREATE TRIGGER\fRでは\fBopaque\fR型を返すよう宣言された関数を受け入れます。
しかし、注意を促すメッセージを表示し、宣言された関数の戻り値型を\fBtrigger\fRに変換します。
.PP
トリガを削除するには、DROP TRIGGER [\fBdrop_trigger\fR(l)]コマンドを使用してください。
.SH "例"
.PP
the documentationに完全な例があります。
.SH "互換性"
.PP
PostgreSQLにおける\fBCREATE TRIGGER\fR文はSQL:1999標準のサブセットを実装したものです。
(SQL-92にはトリガについての規定はありません。)
次の機能が欠落しています。
.TP 0.2i
\(bu
SQL:1999では、指定した列への更新時に起動するトリガが可能です。
(例えば、AFTER UPDATE OF col1, col2)
.TP 0.2i
\(bu
SQL:1999では、``old''と``new''の別名や、トリガで起動される動作定義で使用されるテーブルに別名を定義することができます。
(例えば、CREATE TRIGGER ... ON tablename REFERENCING OLD ROW AS somename NEW ROW AS othername ...)。
PostgreSQLでは、トリガプロシージャを任意数のユーザ定義言語で作成することができますので、データへのアクセスは言語固有の方法で扱われます。
.TP 0.2i
\(bu
PostgreSQLでは、トリガの動作として、ユーザ定義の関数を実行させることしかできません。
SQL:1999では、他のSQLコマンドを複数実行させることができます。
例えば、トリガ動作として\fBCREATE TABLE\fRを実行させることができます。
この制限を回避する方法は簡単で、実行させたいコマンドを実行するユーザ定義関数を作成することです。
.PP
.PP
SQL:1999では、複数のトリガは、作成時刻順に起動すべきであると規定しています。
PostgreSQLでは名前順であり、その動作の判断がより簡単になっています。
.PP
ORを使用した単一トリガにおける複数の動作指定機能は、標準SQLに対する PostgreSQLの拡張です。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)], ALTER TRIGGER [\fBalter_trigger\fR(l)], DROP TRIGGER [\fBdrop_trigger\fR(l)]
