.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_gettype" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_gettype \- 指定された列のデータ型名を返します。

.SH SYNOPSIS
.sp
.nf
char * SPI_gettype(TupleDesc \fIrowdesc\fR, int \fIcolnumber\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_gettype\fR は指定された列のデータ型名のコピーを返します。
(不要になった段階で、\fBpfree\fRを使用して名前のコピーを解放することができます。)
.SH "引数"
.TP
\fBTupleDesc \fIrowdesc\fB\fR
入力行の記述。
.TP
\fBint \fIcolnumber\fB\fR
(1から始まる)行番号。
.SH "戻り値"
.PP
指定された列のデータ型名。
エラー時は\fBNULL\fRです。
エラー時、SPI_resultは\fBSPI_ERROR_NOATTRIBUTE\fRに設定されます。
