.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER OPERATOR" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER OPERATOR \- 演算子の定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER OPERATOR \fIname\fR ( { \fIlefttype\fR | NONE } , { \fIrighttype\fR | NONE } ) OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER OPERATOR\fRは演算子の定義を変更します。
今の所、演算子の所有者を変更する機能のみが使用できます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の演算子の名前です。(スキーマ修飾名も可。)
.TP
\fB\fIlefttype\fB\fR
演算子の左オペランドのデータ型です。
左オペランドがない演算子の場合はNONEと書いてください。
.TP
\fB\fIrighttype\fB\fR
演算子の右オペランドのデータ型です。
右オペランドがない演算子の場合はNONEと書いてください。
.TP
\fB\fInewowner\fB\fR
新しい演算子の所有者です。
演算子の所有者を変更するにはスーパーユーザでなければなりません。
.SH "例"
.PP
独自の\fBtext\fR型用のa @@ b演算子の所有者を変更します。
.sp
.nf
ALTER OPERATOR @@ (text, text) OWNER TO joe;
.sp
.fi
.SH "互換性"
.PP
標準SQLには \fBALTER OPERATOR\fR 文はありません。
.SH "関連項目"
CREATE OPERATOR [\fBcreate_operator\fR(l)], DROP OPERATOR [\fBdrop_operator\fR(l)]
