.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TYPE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER TYPE \- 型定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER TYPE \fIname\fR OWNER TO \fInew_owner\fR 
  
.sp
.fi
.SH "説明"
.PP
\fBALTER TYPE\fRは既存の型の定義を変更します。
現在、型の所有者を変更することだけを行なうことができます。
.SH "パラメータ"
.PP
.TP
\fB\fIname\fB\fR
変更対象の既存の型の名前です(スキーマ修飾も可)。
.TP
\fB\fInew_owner\fB\fR
新しい型の所有者のユーザ名です。
型の所有者を変更するにはスーパーユーザでなければなりません。
.PP
.SH "例"
.PP
emailユーザ定義型の所有者をjoeに変更します。
.sp
.nf
ALTER TYPE email OWNER TO joe;
   
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBALTER TYPE\fR文はありません。
