.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP OPERATOR" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP OPERATOR \- 演算子の削除

.SH SYNOPSIS
.sp
.nf
DROP OPERATOR \fIname\fR ( { \fIlefttype\fR | NONE } , { \fIrighttype\fR | NONE } ) [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP OPERATOR\fRはデータベースシステムから既存の演算子を削除します。
このコマンドを実行するには、その演算子の所有者でなければなりません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の演算子の名前です。(スキーマ修飾名でも可。)
.TP
\fB\fIlefttype\fB\fR
演算子の左項のデータ型です。
演算子に左項が無い場合は、NONEと記述してください。
.TP
\fB\fIrighttype\fB\fR
演算子の右項のデータ型です。
演算子に右項が無い場合は、NONEと記述してください。
.TP
\fBCASCADE\fR
演算子に依存するオブジェクトを自動的に削除します。
.TP
\fBRESTRICT\fR
依存するオブジェクトがある場合、演算子の削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
\fBinteger\fR型用のa^nという巾乗演算子を削除します。
.sp
.nf
DROP OPERATOR ^ (integer, integer);
.sp
.fi
.PP
\fBbit\fR型用の~bというビット列否定左単項演算子を削除します。
.sp
.nf
DROP OPERATOR ~ (none, bit);
.sp
.fi
.PP
\fBbigint\fR型用のx!階乗右単項演算子を削除します。
.sp
.nf
DROP OPERATOR ! (bigint, none);
.sp
.fi
.SH "互換性"
.PP
標準SQLには\fBDROP OPERATOR\fR文はありません。
.SH "関連項目"
CREATE OPERATOR [\fBcreate_operator\fR(l)], ALTER OPERATOR [\fBalter_operator\fR(l)]
