.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER FUNCTION" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER FUNCTION \- 関数定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER FUNCTION \fIname\fR ( [ \fItype\fR [, ...] ] ) RENAME TO \fInewname\fR
ALTER FUNCTION \fIname\fR ( [ \fItype\fR [, ...] ] ) OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER FUNCTION\fRは関数定義を変更します。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の関数名です。(スキーマ修飾名も可。)
.TP
\fB\fItype\fB\fR
関数の引数のデータ型です。
.TP
\fB\fInewname\fB\fR
新しい関数名です。
.TP
\fB\fInewowner\fB\fR
新しい関数の所有者です。
関数の所有者を変更するには、スーパーユーザでなければなりません。
関数にSECURITY DEFINER印が付いている場合、その後の関数は新しい所有者の権限で実行されることになることに注意してください。
.SH "例"
.PP
\fBinteger\fR型用のsqrt関数の名前をsquare_rootに変更します。
.sp
.nf
ALTER FUNCTION sqrt(integer) RENAME TO square_root;
.sp
.fi
.PP
\fBinteger\fR型用のsqrt関数の所有者をjoeに変更します。
.sp
.nf
ALTER FUNCTION sqrt(integer) OWNER TO joe;
.sp
.fi
.SH "互換性"
.PP
標準SQLに\fBALTER FUNCTION\fR文はありますが、関数名や所有者を変更するオプションを提供していません。
.SH "関連項目"
CREATE FUNCTION [\fBcreate_function\fR(l)], DROP FUNCTION [\fBdrop_function\fR(l)]
