.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_cursor_move" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_cursor_move \- カーソルを移動します

.SH SYNOPSIS
.sp
.nf
void SPI_cursor_move(Portal \fIportal\fR, bool \fIforward\fR, int \fIcount\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_cursor_move\fR はカーソル内で、数行を飛ばします。
これは\fBMOVE\fR SQLコマンドと等価です。
.SH "引数"
.TP
\fBPortal \fIportal\fB\fR
カーソルを持つポータル。
.TP
\fBbool \fIforward\fB\fR
前方方向の移動の場合、真。後方方向の場合は偽。
.TP
\fBint \fIcount\fB\fR
移動する最大行数。
