.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER TABLE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER TABLE \- テーブル定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER TABLE [ ONLY ] \fIname\fR [ * ]
    \fIaction\fR [, ... ]
ALTER TABLE [ ONLY ] \fIname\fR [ * ]
    RENAME [ COLUMN ] \fIcolumn\fR TO \fInew_column\fR
ALTER TABLE \fIname\fR
    RENAME TO \fInew_name\fR

ここで、\fIaction\fRは以下のいずれかです。

    ADD [ COLUMN ] \fIcolumn\fR \fItype\fR [ \fIcolumn_constraint\fR [ ... ] ]
    DROP [ COLUMN ] \fIcolumn\fR [ RESTRICT | CASCADE ]
    ALTER [ COLUMN ] \fIcolumn\fR TYPE \fItype\fR [ USING \fIexpression\fR ]
    ALTER [ COLUMN ] \fIcolumn\fR SET DEFAULT \fIexpression\fR
    ALTER [ COLUMN ] \fIcolumn\fR DROP DEFAULT
    ALTER [ COLUMN ] \fIcolumn\fR { SET | DROP } NOT NULL
    ALTER [ COLUMN ] \fIcolumn\fR SET STATISTICS \fIinteger\fR
    ALTER [ COLUMN ] \fIcolumn\fR SET STORAGE { PLAIN | EXTERNAL | EXTENDED | MAIN }
    ADD \fItable_constraint\fR
    DROP CONSTRAINT \fIconstraint_name\fR [ RESTRICT | CASCADE ]
    CLUSTER ON \fIindex_name\fR
    SET WITHOUT CLUSTER
    SET WITHOUT OIDS
    OWNER TO \fInew_owner\fR
    SET TABLESPACE \fItablespace_name\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER TABLE\fRは既存のテーブルの定義を変更します。 
このコマンドには、いくつか副形式があります。
.TP
\fBADD COLUMN\fR
この形式を使用すると、CREATE TABLE [\fBcreate_table\fR(l)]と同じ構文を使って新しい列をテーブルに追加できます。
.TP
\fBDROP COLUMN\fR
この形式を使用すると、テーブルから列を削除できます。 
削除する列を含んでいるインデックスおよびテーブル制約も自動的に削除されます。 
また、削除する列にテーブル外のもの (例えば、外部キー制約、ビュー、など) が依存している場合、CASCADEを付ける必要があります。
.TP
\fBALTER COLUMN TYPE\fR
この形式を使用すると、テーブルの列の型を変更できます。
その列を含むインデックスと簡単なテーブル制約は、元々与えられた式を再解析して新しい列の型を使用するように自動的に変換されます。
省略可能なUSING句は、古い列値からどのように新しい値を計算するかを指定します。
省略された場合、デフォルトの変換は、古いデータ型から新しいデータ型への代入時のキャストと同じです。
古いデータ型から新しいデータ型への暗黙あるいは代入時のキャストがない場合、USING句を指定しなければなりません。
.TP
\fBSET/DROP DEFAULT\fR
これらの形式を使用すると、列のデフォルト値を設定または削除できます。
このデフォルト値はこの変更後に行なわれる\fBINSERT\fRコマンドのみに適用されます。 
テーブル内の既存の行は変更されません。 
ビューにもデフォルトを設定可能です。
この場合、ビューのON INSERTルールが適用される前に、ビューの\fBINSERT\fR文にデフォルトが挿入されます。
.TP
\fBSET/DROP NOT NULL\fR
これらの形式を使用すると、列で NULL 値を使用できるかどうか設定できます。
SET NOT NULLは、そのテーブルの列にNULL値がひとつもない場合にのみ設定可能です。
.TP
\fBSET STATISTICS\fR
この形式を使用すると、コマンド実行後に行なわれるANALYZE [\fBanalyze\fR(l)]操作において、列単位での統計情報収集対象を設定できます。 
対象は、0から1000までの範囲で設定可能です。
また、対象を-1に設定すると、システムのデフォルト統計情報対象(default_statistics_target)が使用されます。
PostgreSQLの問い合わせプランナによる統計情報の使用に関する詳細は、the documentationを参照してください。

.TP
\fBSET STORAGE\fR
この形式を使用すると、列の保管モードを設定します。 
これにより、この列をインラインで保持するか、あるいは補足テーブルに保持するか、また、データを圧縮するかどうかを制御できます。
PLAINは、\fBinteger\fRのような固定長の値に対して使用しなければならず、インラインで保持されていて圧縮されません。
MAINは、インラインで保持されていて、圧縮可能なデータに使用します。
EXTERNALは圧縮されていない外部データに使用します。
EXTENDEDは圧縮された外部データに使用します。
EXTENDEDは、PLAIN以外の保管をサポートするほとんどのデータ型でのデフォルトです。
EXTERNALを使用すると、\fBtext\fRおよび\fBbytea\fR列に対する部分文字列操作をより速く処理できますが、保管容量が増えるというデメリットがあります。
SET STORAGEそのものはテーブルを全く変更しないことに注意してください。
これは単に将来のテーブルの更新時に遂行される戦略を設定するだけです。
詳細はthe documentationを参照してください。
.TP
\fBADD \fItable_constraint\fB\fR
この形式を使用すると、CREATE TABLE [\fBcreate_table\fR(l)]と同じ構文を使って新しい制約をテーブルに追加できます。 
.TP
\fBDROP CONSTRAINT\fR
この形式を使用すると、テーブルの制約を削除できます。 
現在、テーブルの制約は、一意な名前である必要はありません。
従って、指定した名前に一致する制約が、複数存在する可能性があります。 
一致した制約は全て削除されます。
.TP
\fBCLUSTER\fR
この形式は、将来のCLUSTER [\fBcluster\fR(l)]操作用のデフォルトインデックスを選択します。
実際のテーブルの再クラスタ化は行ないません。
.TP
\fBSET WITHOUT CLUSTER\fR
この形式は、テーブルから最も最近に使用されたCLUSTER [\fBcluster\fR(l)]インデックス指定を削除します。
これは、今後のインデックスを指定しないクラスタ操作に影響を与えます。
.TP
\fBSET WITHOUT OIDS\fR
この形式は、テーブルからoidシステム列を削除します。
これは、既にoid列が存在しない場合であっても警告が現れないという点を除いて、DROP COLUMN oid RESTRICTと全く同じです。

OIDを削除した後にOIDを再度テーブルに保存させる\fBALTER TABLE\fRの変種は存在しないことに注意してください。
.TP
\fBOWNER\fR
この形式を使用すると、テーブル、インデックス、シーケンス、またはビューの所有者を、指定したユーザに変更できます。
.TP
\fBSET TABLESPACE\fR
この形式を使用すると、テーブルのテーブル空間を指定したテーブル空間に変更し、テーブルに関連するデータファイルを新しいテーブル空間に移動することができます。
テーブルにインデックスがあったとしても移動されません。
これらは別途SET TABLESPACEコマンドを実行することで移動することができます。
CREATE TABLESPACE [\fBcreate_tablespace\fR(l)]も参照してください。
.TP
\fBRENAME\fR
RENAME 形式を使用すると、テーブル (もしくは、インデックス、シーケンス、またはビュー) の名前や、テーブルの個々の列名を変更できます。 
格納されているデータへの影響はありません。
.PP
.PP
RENAME以外の全ての操作は、組み合わせて複数の変更操作のリストとすることができ、それらは並行に適用されます。
例えば、複数の列を追加することも、複数列の型を変更することも、そしてこの追加と変更を単一のコマンドで実行することができます。
これは特に巨大なテーブルでは便利です。変更のために必要なテーブル全体の走査が1回で済むからです。
.PP
\fBALTER TABLE\fRコマンドを使用するには、変更するテーブルを所有している必要があります。
ただし、\fBALTER TABLE OWNER\fRコマンドは例外です。
このコマンドは、スーパーユーザのみ実行可能です。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
変更対象となる既存のテーブルの名前です (スキーマ修飾名も可)。 
ONLYが指定された場合、そのテーブルのみが変更されます。 
ONLYが指定されていない場合、そのテーブルおよび (存在する場合は) それを継承する全てのテーブルが更新されます。 
テーブル名に *を付けることで継承テーブルが変更されることを表すことができますが、現在のバージョンでは、これはデフォルトで行われます。 
(7.1より前のリリースでは、ONLY がデフォルトでした。 
このデフォルトの設定は、sql_inheritance設定オプションで変更できます。)
.TP
\fB\fIcolumn\fB\fR
新規または既存の列の名前です。
.TP
\fB\fInew_column\fB\fR
既存の列の新しい名前です。
.TP
\fB\fInew_name\fB\fR
テーブルの新しい名前です。
.TP
\fB\fItype\fB\fR
新しい列のデータ型、もしくは、既存の列に対する新しいデータ型です。
.TP
\fB\fItable_constraint\fB\fR
テーブルの新しいテーブル制約です。
.TP
\fB\fIconstraint_name\fB\fR
削除する既存の制約の名前です。
.TP
\fBCASCADE\fR
削除された列や制約に依存しているオブジェクト (たとえば、削除された列を参照しているビューなど) を、自動的に削除します。
.TP
\fBRESTRICT\fR
依存しているオブジェクトがある場合、列または制約の削除要求を拒否します。 
これがデフォルトの動作です。
.TP
\fB\fIindex_name\fB\fR
指定したインデックス名でテーブルをクラスタ化するように印をつけます。
.TP
\fB\fInew_owner\fB\fR
テーブルの新しい所有者のユーザ名です。
.TP
\fB\fItablespace_name\fB\fR
テーブルを移動する先のテーブル空間の名前です。
.SH "注釈"
.PP
COLUMNキーワードはノイズであり、省略可能です。
.PP
ADD COLUMNによって列が追加される時、テーブル内の全ての既存行は、その列のデフォルト値(DEFAULTが指定されなかった場合はNULL)で初期化されます。
.PP
非NULLのデフォルト値を持つ列を追加する、あるいは、既存の列の型を変更することは、テーブル全体を書き換えることが必要になります。
巨大なテーブルでは非常に時間がかかる可能性があり、また、一時的に2倍のディスク容量が必要とされます。
.PP
CHECKあるいはNOT NULL制約を追加することは、既存の行が制約に従うかどうかを検証するためのテーブルの走査が必要になります。
.PP
単一の\fBALTER TABLE\fR内に複数の変更を指定できるオプションを提供する主な理由は、複数のテーブル走査や書き換えを1回のテーブル走査にまとめることができるようにすることです。
.PP
DROP COLUMN形式は、物理的には列を削除せずに、単にSQLを操作する上で不可視にします。 
コマンド実行後、そのテーブルに挿入または更新が行なわれると、その列にNULLが格納されます。 
従って、列の削除は短時間で行えます。
しかし、削除された列が占めていた領域がまだ回収されていないため、テーブルのディスク上のサイズはすぐには小さくなりません。 
その領域は、その後既存の行が更新されると、回収されます。 
.PP
ALTER TYPEがテーブル全体の書き換えを必要とすることは利点となる場合があります。
この書き換え処理によって、テーブル内の不要となった領域を除去されるからです。
例えば、削除された列によって占有されていた領域を即座に回収するには、以下のコマンドが最も高速です。
.sp
.nf
ALTER TABLE table ALTER COLUMN anycol TYPE anytype;
.sp
.fi
ここで、anycolは既存のテーブル列を、anytypeは既存の列と同一の型を示します。
この結果、テーブルには目に見えるような有意な変更はありませんが、このコマンドは不要となったデータを取り除く、強制的な書き換えを行ないます。
.PP
ALTER TYPEのUSINGオプションでは実際、行の古い値を使用する式を指定することができます。
つまり、変換対象の列もその他の列も参照することができます。
これにより、非常に一般的な変換をALTER TYPE構文で行うことができます。
この柔軟性のため、USING式は(あったとしても)列のデフォルト値には適用できません。
この結果は、デフォルトで要求される定数式にならない可能性があるためです。
これは、古い型から新しい型への暗黙キャストや代入キャストが存在しない場合、USINGが指定されていたとしても、ALTER TYPEがデフォルトの変換に失敗する可能性があることを意味します。
こうした場合、DROP DEFAULTでデフォルトを削除し、ALTER TYPEを行い、そして、SET DEFAULTを使用して適切な新しいデフォルトを付けてください。
同様の検討はその列を持つインデックスと制約にも適用されます。
.PP
テーブルに、そのテーブルを継承するテーブルがある場合、継承しているテーブルに同じ処理を実行しなければ、親テーブルに列を追加、もしくは列名の変更、列型の変更を実行することはできません。
つまり、\fBALTER TABLE ONLY\fRコマンドは受け付けられません。 
この制限により、継承しているテーブルでは、常に親テーブルと列が一致していることが保証されます。
.PP
再帰的なDROP COLUMN操作では、継承テーブルが他の親テーブルからその列を継承しておらず、かつ、独立した列定義を持っていない場合にのみ、その継承テーブルの列を削除します。 
再帰的でないDROP COLUMN(例えば、\fBALTER TABLE ONLY ... DROP COLUMN\fRなど) では、継承している列は削除しません。
しかし、削除する代わりに、これらの列は継承されておらず独立して定義されているという印を付けます。
.PP
システムカタログテーブルのいかなる部分も変更することは許可されていません。
.PP
有効なパラメータの詳しい説明はCREATE TABLE [\fBcreate_table\fR(l)]を参照してください。
the documentationに、継承に関する更に詳しい情報があります。
.SH "例"
.PP
\fBvarchar\fR 型の列をテーブルに追加します。
.sp
.nf
ALTER TABLE distributors ADD COLUMN address varchar(30);
.sp
.fi
.PP
テーブルから列を削除します。
.sp
.nf
ALTER TABLE distributors DROP COLUMN address RESTRICT;
.sp
.fi
.PP
1つの操作で既存の2列の型を変更します。
.sp
.nf
ALTER TABLE distributors
    ALTER COLUMN address TYPE varchar(80),
    ALTER COLUMN name TYPE varchar(100);
.sp
.fi
.PP
USING句を使用して、UNIXタイムスタンプを持つinteger型の列を\fBtimestamp with time zone\fRに変更します。
.sp
.nf
ALTER TABLE foo
    ALTER COLUMN foo_timestamp TYPE timestamp with time zone
    USING
        timestamp with time zone 'epoch' + foo_timestamp * interval '1 second';
.sp
.fi
.PP
既存の列の名前を変更します。
.sp
.nf
ALTER TABLE distributors RENAME COLUMN address TO city;
.sp
.fi
.PP
既存のテーブルの名前を変更します。
.sp
.nf
ALTER TABLE distributors RENAME TO suppliers;
.sp
.fi
.PP
列に非NULL制約を付与します。
.sp
.nf
ALTER TABLE distributors ALTER COLUMN street SET NOT NULL;
.sp
.fi
列から非NULL制約を削除します。
.sp
.nf
ALTER TABLE distributors ALTER COLUMN street DROP NOT NULL;
.sp
.fi
.PP
テーブルにCHECK制約を付与します。
.sp
.nf
ALTER TABLE distributors ADD CONSTRAINT zipchk CHECK (char_length(zipcode) = 5);
.sp
.fi
.PP
テーブルとその子テーブルからCHECK制約を削除します。
.sp
.nf
ALTER TABLE distributors DROP CONSTRAINT zipchk;
.sp
.fi
.PP
テーブルに外部キー制約を付与します。
.sp
.nf
ALTER TABLE distributors ADD CONSTRAINT distfk FOREIGN KEY (address) REFERENCES addresses (address) MATCH FULL;
.sp
.fi
.PP
テーブルに(複数列の)一意性制約を付与します。
.sp
.nf
ALTER TABLE distributors ADD CONSTRAINT dist_id_zipcode_key UNIQUE (dist_id, zipcode);
.sp
.fi
.PP
自動的に命名されるプライマリキー制約をテーブルに付与します。 
テーブルは1つのみのプライマリキーしか持つことができない点には注意して下さい。
.sp
.nf
ALTER TABLE distributors ADD PRIMARY KEY (dist_id);
.sp
.fi
.PP
テーブルを別のテーブル空間に移動します。
.sp
.nf
ALTER TABLE distributors SET TABLESPACE fasttablespace;
.sp
.fi
.SH "互換性"
.PP
ADD、DROP、SET DEFAULT形式は標準SQLに従います。
他の形式は標準SQLに対するPostgreSQLの拡張です。
また、単一の\fBALTER TABLE\fRコマンド内に複数の操作を指定する機能も拡張です。
.PP
\fBALTER TABLE DROP COLUMN\fRを使用して、テーブルから列のみを削除して、列が無いテーブルを作成することができます。
これは、列が無いテーブルを許可しないSQLからの拡張です。
