.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "DROP SCHEMA" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
DROP SCHEMA \- スキーマの削除

.SH SYNOPSIS
.sp
.nf
DROP SCHEMA \fIname\fR [, ...] [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBDROP SCHEMA\fRはデータベースからスキーマを削除します。
.PP
スキーマを削除できるのは、所有者またはスーパーユーザのみです。 
所有者は、スキーマ内に所有していないオブジェクトが含まれている場合でも、そのスキーマ(およびそこに含まれる全てのオブジェクト)を削除できます。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
スキーマの名前です。
.TP
\fBCASCADE\fR
スキーマに含まれるオブジェクト(テーブル、関数など)を自動的に削除します。
.TP
\fBRESTRICT\fR
スキーマにオブジェクトが含まれている場合は、そのスキーマの削除を拒否します。
これがデフォルトです。
.SH "例"
.PP
データベースからmystuffスキーマ、およびそこに含まれる全てのものを削除します。
.sp
.nf
DROP SCHEMA mystuff CASCADE;
.sp
.fi
.SH "互換性"
.PP
\fBDROP SCHEMA\fRは、標準SQLでは1度のコマンド実行につき1つのスキーマしか削除できないという点を除き、標準SQLと完全に互換性があります。
.SH "関連項目"
ALTER SCHEMA [\fBalter_schema\fR(l)], CREATE SCHEMA [\fBcreate_schema\fR(l)]
