.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "BEGIN" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
BEGIN \- トランザクションブロックの開始

.SH SYNOPSIS
.sp
.nf
BEGIN [ WORK | TRANSACTION ] [ \fItransaction_mode\fR [, ...] ]

ここで\fItransaction_mode\fRは以下のいずれかです。

    ISOLATION LEVEL { SERIALIZABLE | REPEATABLE READ | READ COMMITTED | READ UNCOMMITTED }
    READ WRITE | READ ONLY
.sp
.fi
.SH "説明"
.PP
\fBBEGIN\fRはトランザクションブロックを初期化します。
つまり、\fBBEGIN\fRコマンドの後の文は全て、明示的なCOMMIT [\fBcommit\fR(l)]またはROLLBACK [\fBrollback\fR(l)]が与えられるまで、単一のトランザクションの中で実行されます。
デフォルト(\fBBEGIN\fR無し)では、PostgreSQLはトランザクションを``自動コミット''で実行します。
言い換えると、各文はそれ固有のトランザクションの中で実行され、コミットはその文の終わりに暗黙的に実行されます（実行が成功した場合です。 そうでない場合はロールバックされます）。 
.PP
トランザクションブロック内では、文はより迅速に実行されます。
なぜなら、トランザクションの開始/コミットには、CPUとディスクにかなり高い負荷がかかるからです。
トランザクション中の複数の文の実行はまた、複数の関連するテーブルを更新するときに確実に一貫性を保つためにも便利です。
関連する更新が全て完了していない中間的な状態を、他のセッションからは参照できません。
.PP
隔離レベルもしくは読み書きモードが指定されている場合、新しいトランザクションは、SET TRANSACTION [\fBset_transaction\fR(l)]が実行された時と同様の特性を持ちます。
.SH "パラメータ"
.TP
\fBWORK\fR
.TP
\fBTRANSACTION\fR
省略可能なキーワード。これらは何も効果がありません。
.PP
この他のこの文用のパラメータの意味についてはSET TRANSACTION [\fBset_transaction\fR(l)]を参照してください。
.PP
.SH "注釈"
.PP
START TRANSACTION [\fBstart_transaction\fR(l)]には、\fBBEGIN\fRと同じような機能があります。
.PP
トランザクションを終了させるにはCOMMIT [\fBcommit\fR(l)]かROLLBACK [\fBrollback\fR(l)]を使用して ください。
.PP
トランザクションブロック内で\fBBEGIN\fRを発行すると、警告メッセージが現われます。
トランザクションの状態には影響ありません。
トランザクションブロック内でトランザクションを入れ子にするには、セーブポイントを使用してください。
(詳細はSAVEPOINT [\fBsavepoint\fR(l)]を参照してください。)
.PP
後方互換性のために、連続する\fItransaction_modes\fR間のカンマを省略することができます。
.SH "例"
.PP
トランザクションブロックを始めます。
.sp
.nf
BEGIN;
.sp
.fi
.SH "互換性"
.PP
\fBBEGIN\fRはPostgreSQLの言語拡張です。
標準SQLのSTART TRANSACTION [\fBstart_transaction\fR(l)]コマンドと等価です。
互換性について追記していますのでこちらも参照してください。
.PP
偶然ですが、BEGINというキーワードは埋め込みSQLでは異なった目的に使われます。
データベースアプリケーションを移植するときはトランザクションの意味で使用されているのかどうか注意するべきでしょう。
.SH "関連項目"
COMMIT [\fBcommit\fR(l)], ROLLBACK [\fBrollback\fR(l)], START TRANSACTION [\fBstart_transaction\fR(l)], SAVEPOINT [\fBsavepoint\fR(l)]
