.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_modifytuple" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_modifytuple \- 与えられた行の選択フィールドを置き換えた行を作成します。

.SH SYNOPSIS
.sp
.nf
HeapTuple SPI_modifytuple(Relation \fIrel\fR, HeapTuple \fIrow\fR, \fIncols\fR, \fIcolnum\fR, Datum * \fIvalues\fR, const char * \fInulls\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_modifytuple\fRは、選択された列は新しい値で置き換え、その他の位置は元の行の列をコピーした、新しい行を作成します。
入力行は変更されません。
.SH "引数"
.TP
\fBRelation \fIrel\fB\fR
行の行記述子のソースとしてのみ使用されます。
(行記述子ではなくリレーションを渡すことは設計ミスです。)
.TP
\fBHeapTuple \fIrow\fB\fR
変更される行。
.TP
\fBint \fIncols\fB\fR
\fIcolnum\fR配列の列番号の数。
.TP
\fBint * \fIcolnum\fB\fR
変更される列番号の配列。
(列番号は1から始まります。)
.TP
\fBDatum * \fIvalues\fB\fR
指定された列の新しい値。
.TP
\fBconst char * \fINulls\fB\fR
もしあれば、どの値がNULLかを表します。
(書式については\fBSPI_execute_plan\fRを参照してください。)
.SH "戻り値"
.PP
変更された新しい行。上位エクゼキュータコンテキストに割り当てられます。
\fIrow\fRが \fBNULL\fRの場合のみ\fBNULL\fR です。
.PP
エラー時、SPI_resultが以下のように設定されます。
.TP
\fBSPI_ERROR_ARGUMENT\fR
\fIrel\fRが\fBNULL\fRの場合、\fIrow\fRが\fBNULL\fRの場合、\fIncols\fRが0以下の場合、\fIcolnum\fRが\fBNULL\fRの場合、\fIvalues\fRが\fBNULL\fRの場合。
.TP
\fBSPI_ERROR_NOATTRIBUTE\fR
\fIcolnum\fRが無効な列番号を持つ場合。
(0以下、\fIrow\fRの列数以上)
.PP
