.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_getargtypeid" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_getargtypeid \- SPI_prepareで準備された計画で指定される引数のデータ型のOIDを返します。

.SH SYNOPSIS
.sp
.nf
Oid SPI_getargtypeid(void * \fIplan\fR, int \fIargIndex\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_getargtypeid\fRは、\fBSPI_prepare\fRで準備された計画における\fIargIndex\fR番目の引数の型IDを表すOIDを返します。
インデックス0は最初の引数を示します。
.SH "引数"
.TP
\fBvoid * \fIplan\fB\fR
（\fBSPI_prepare\fRで返される）実行計画です。
.TP
\fBint \fIargIndex\fB\fR
0から始まる引数のインデックスです。
.SH "戻り値"
.PP
指定したインデックスにおける引数の型IDです。
\fIplan\fRが\fBNULL\fR、あるいは、\fIargIndex\fRが0未満、\fIplan\fRで宣言された引数の数以上の場合、\fBSPI_ERROR_ARGUMENT\fRが返ります。
