.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "CREATE CONSTRAINT TRIGGER" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
CREATE CONSTRAINT TRIGGER \- 新しい制約トリガの定義

.SH SYNOPSIS
.sp
.nf
CREATE CONSTRAINT TRIGGER \fIname\fR
    AFTER \fIevents\fR ON
    \fItablename\fR \fIconstraint\fR \fIattributes\fR
    FOR EACH ROW EXECUTE PROCEDURE \fIfuncname\fR ( \fIargs\fR )
.sp
.fi
.SH "説明"
.PP
\fBCREATE CONSTRAINT TRIGGER\fRは、\fBCREATE TABLE\fR/\fBALTER TABLE\fRの中で、または\fBpg_dump\fRによって使用され、参照整合性用の特殊なトリガを作成します。
一般的な使用を意図したものではありません。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
制約トリガの名前です。
.TP
\fB\fIevents\fB\fR
このトリガが実行されるイベントの種類です。
.TP
\fB\fItablename\fB\fR
トリガイベントが発生するテーブルの名前です (スキーマ修飾名の場合もあります)。
.TP
\fB\fIconstraint\fB\fR
制約の実仕様です。
.TP
\fB\fIattributes\fB\fR
制約属性です。
.TP
\fB\fIfuncname\fB(\fIargs\fB)\fR
トリガの処理部分として呼び出される関数です。
