.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "REVOKE" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
REVOKE \- アクセス権限の取り上げ

.SH SYNOPSIS
.sp
.nf
REVOKE [ GRANT OPTION FOR ]
    { { SELECT | INSERT | UPDATE | DELETE | RULE | REFERENCES | TRIGGER }
    [,...] | ALL [ PRIVILEGES ] }
    ON [ TABLE ] \fItablename\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { { CREATE | TEMPORARY | TEMP } [,...] | ALL [ PRIVILEGES ] }
    ON DATABASE \fIdbname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { EXECUTE | ALL [ PRIVILEGES ] }
    ON FUNCTION \fIfuncname\fR ([\fItype\fR, ...]) [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { USAGE | ALL [ PRIVILEGES ] }
    ON LANGUAGE \fIlangname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { { CREATE | USAGE } [,...] | ALL [ PRIVILEGES ] }
    ON SCHEMA \fIschemaname\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]

REVOKE [ GRANT OPTION FOR ]
    { CREATE | ALL [ PRIVILEGES ] }
    ON TABLESPACE \fItablespacename\fR [, ...]
    FROM { \fIusername\fR | GROUP \fIgroupname\fR | PUBLIC } [, ...]
    [ CASCADE | RESTRICT ]
.sp
.fi
.SH "説明"
.PP
\fBREVOKE\fRコマンドは、1つ以上のユーザあるいはユーザグループから以前に与えられた権限を取り上げます。
PUBLICキーワードは暗黙的に定義された全ユーザからなるグループです。
.PP
権限の種類の意味についてはGRANT [\fBgrant\fR(l)]コマンドの説明を参照してください。
.PP
個々のユーザは全て、ユーザに直接許可された権限、ユーザが現在属しているグループに許可された権限、そして、PUBLICに許可された権限を合わせた権限を持っていることに注意してください。
従って、例えば、PUBLICからSELECT権限を取り上げることは、必ずしもそのオブジェクトに対するSELECT権限を全てのユーザが失うことを意味しません。
直接、あるいは、グループ経由で許可されたユーザは、その権限を持ち続けます。
.PP
GRANT OPTION FORが指定された場合、権限自体ではなく、その権限のグラントオプションのみが取り上げられます。
指定されていない場合、権限とグラントオプションの両方とも取り上げられます。
.PP
ユーザがグラントオプションを持つ権限を保持し、その権限を他ユーザに与えていた場合、他のユーザが保持する権限は依存権限と呼ばれます。
最初のユーザが持つ権限やグラントオプションが取り上げられ、かつ、依存権限が存在する場合、CASCADEが指定されると依存権限もまた取り上げられ、指定されていなければ、権限の取り上げが失敗します。
この再帰的な取り上げは、REVOKEを実行したユーザが追跡可能なユーザの連鎖を通して与えられた権限にのみ影響します。
従って、もし、権限が他のユーザを介して与えられたならば、影響を受けるユーザは実際にはその権限を保持する場合もあります。
.SH "注釈"
.PP
既存オブジェクトに付与された権限を表示するには\fBpsql\fR(1)の\fB\\z\fRコマンドを使用してください。
この書式についてはGRANT [\fBgrant\fR(l)]を参照してください。
.PP
ユーザが直接付与した権限のみをそのユーザは取り上げることができます。
例えば、もし、ユーザAがグラントオプションを付けてユーザBに権限を与え、その後、ユーザBがユーザCにその権限を与えたとすると、ユーザAはユーザCの権限を直接取り上げることはできません。
その代わり、ユーザAはユーザBからグラントオプションを、CASCADEオプションを付けて取り上げることで、ユーザCに与えられた権限も続いて取り上げることができます。
他の例を挙げると、AとBの両方が同じ権限をCに与えたとすると、AはAの与えた権限を取り上げることはできますが、Bの与えた権限を取り上げることはできません。
従って、Cは実質的にその権限を持ち続けることになります。
.PP
オブジェクトの所有者以外がそのオブジェクト上の権限に対して\fBREVOKE\fRを実行すると、ユーザがオブジェクトに何らかの権限を持っていない限り、コマンドは権限外のために失敗します。
何らかの権限がある限り、コマンドは進行しますが、そのユーザがグラントオプションを持つ権限のみを取り上げることができます。
権限を全く持たない場合は、\fBREVOKE ALL PRIVILEGES\fR形式は警告を出力します。
他の形式では、そのコマンドで指名した権限のいずれかに対するグラントオプションを持たない場合に警告を出力します。
（原理上、上の説明はオブジェクト所有者にも適用されますが、所有者は常に全てのグラントオプションを保持していますので、こうした問題は発生することはありません。）
.PP
スーパーユーザが\fBGRANT\fRや\fBREVOKE\fRコマンドの発行を選択した場合、そのコマンドは、対象のオブジェクトの所有者によって発行されたかのように動作します。
根本的に全ての権限はオブジェクトの所有者から渡されるもの(グラントオプションの連鎖による間接的な場合もあります)ですので、スーパーユーザは、全ての権限を取り上げることができます。
しかし、これには上述のCASCADEを使用する必要があります。
.SH "例"
.PP
filmsテーブルから、publicに与えた挿入権限を取り上げます。
.sp
.nf
REVOKE INSERT ON films FROM PUBLIC;
.sp
.fi
.PP
kindsビューから、manuelユーザに与えた全ての権限を取り上げます。
.sp
.nf
  
REVOKE ALL PRIVILEGES ON kinds FROM manuel;
.sp
.fi
実質、これは``私が与えた全ての権限を取り上げる''ことを意味します。
.SH "互換性"
.PP
GRANT [\fBgrant\fR(l)]コマンドの互換性についての注釈は\fBREVOKE\fRにも当てはまります。
構文の要約を以下に示します。
.sp
.nf
REVOKE [ GRANT OPTION FOR ] \fIprivileges\fR
    ON \fIobject\fR [ ( \fIcolumn\fR [, ...] ) ]
    FROM { PUBLIC | \fIusername\fR [, ...] }
    { RESTRICT | CASCADE }
.sp
.fi
標準に従うとRESTRICTかCASCADEのどちらかが必要です。
しかし、PostgreSQLではデフォルトでRESTRICTと仮定しています。
.SH "関連項目"
.PP
GRANT [\fBgrant\fR(l)]
