.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "RESET" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
RESET \- 実行時パラメータの値をデフォルト値に戻す

.SH SYNOPSIS
.sp
.nf
RESET \fIname\fR
RESET ALL
.sp
.fi
.SH "説明"
.PP
\fBRESET\fRは実行時パラメータをデフォルト値に戻します。
\fBRESET\fRは下記のように記述することもできます。
.sp
.nf
SET \fIparameter\fR TO DEFAULT
.sp
.fi
詳細はSET [\fBset\fR(l)]を参照してください。
.PP
デフォルト値は、現行セッション内で \fBSET\fRコマンドが発行されない場合に変数が保持していた値として定義されます。
この値の実際の出所は、コンパイル済みのデフォルトか、設定ファイル、コマンドラインオプション、あるいは、データベース毎ユーザ毎のデフォルト設定のどれかとなります。
詳細はthe documentationを参照してください。
.PP
\fBRESET\fRのトランザクションでの振舞いの詳細は、\fBSET\fRマニュアルページを参照してください。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
実行時パラメータの名前です。
一覧についてはSET [\fBset\fR(l)]を参照してください。
.TP
\fBALL\fR
設定可能な全ての実行時パラメータをデフォルト値に戻します。
.SH "例"
.PP
geqo設定変数をデフォルト値に設定します。
.sp
.nf
RESET geqo;
.sp
.fi
.SH "互換性"
.PP
\fBRESET\fRはPostgreSQLの拡張です。
