.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "ALTER OPERATOR CLASS" "" "2005-01-19" "SQL - 言語" "SQL コマンド"
.SH NAME
ALTER OPERATOR CLASS \- 演算子クラスの定義の変更

.SH SYNOPSIS
.sp
.nf
ALTER OPERATOR CLASS \fIname\fR USING \fIindex_method\fR RENAME TO \fInewname\fR
ALTER OPERATOR CLASS \fIname\fR USING \fIindex_method\fR OWNER TO \fInewowner\fR
.sp
.fi
.SH "説明"
.PP
\fBALTER OPERATOR CLASS\fRは演算子クラスの定義を変更します。
.SH "パラメータ"
.TP
\fB\fIname\fB\fR
既存の演算子クラスの名前です。(スキーマ修飾名も可。)
.TP
\fB\fIindex_method\fB\fR
その演算子クラス用のインデックスメソッドの名前です。
.TP
\fB\fInewname\fB\fR
新しい演算子クラス名です。
.TP
\fB\fInewowner\fB\fR
新しい演算子クラスの所有者です。
演算子クラスの所有者を変更するにはスーパーユーザでなければなりません。
.SH "互換性"
.PP
標準SQLには\fBALTER OPERATOR CLASS\fR文はありません。
.SH "関連項目"
CREATE OPERATOR CLASS [\fBcreate_operator_class\fR(l)], DROP OPERATOR CLASS [\fBdrop_operator_class\fR(l)]
