.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_copytuple" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_copytuple \- 上位エクゼキュータ内に行のコピーを作成します。

.SH SYNOPSIS
.sp
.nf
HeapTuple SPI_copytuple(HeapTuple \fIrow\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_copytuple\fRは上位エクゼキュータコンテキスト内に行のコピーを作成します。
これは通常、トリガから変更した行を返す時に使用されます。
複合型を返すものと宣言された関数では、代わりに\fBSPI_returntuple\fRを使用してください。
.SH "引数"
.TP
\fBHeapTuple \fIrow\fB\fR
コピーされる行。
.SH "戻り値"
.PP
コピーされた行。
\fItuple\fR が \fBNULL\fRの場合のみ\fBNULL\fRです。
