.\\" auto-generated by docbook2man-spec $Revision: 1.2 $
.TH "SPI_palloc" "" "2005-01-19" "" "PostgreSQL 8.0.2 文書"
.SH NAME
SPI_palloc \- 上位エクゼキュータコンテキスト内にメモリを割り当てます。

.SH SYNOPSIS
.sp
.nf
void * SPI_palloc(Size \fIsize\fR)
.sp
.fi
.SH "説明"
.PP
\fBSPI_palloc\fRは、上位エクゼキュータコンテキスト内にメモリを割り当てます。
.SH "引数"
.TP
\fBSize \fIsize\fB\fR
割り当てる領域のバイト数。
.SH "戻り値"
.PP
指定サイズの新しい格納領域へのポインタ。
